# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tecton_proto/metadataservice/metadata_service__client.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from tecton_proto.amplitude import amplitude__client_pb2 as tecton__proto_dot_amplitude_dot_amplitude____client__pb2
from tecton_proto.amplitude import client_logging__client_pb2 as tecton__proto_dot_amplitude_dot_client__logging____client__pb2
from tecton_proto.args import feature_view__client_pb2 as tecton__proto_dot_args_dot_feature__view____client__pb2
from tecton_proto.auditlog import metadata__client_pb2 as tecton__proto_dot_auditlog_dot_metadata____client__pb2
from tecton_proto.auth import principal__client_pb2 as tecton__proto_dot_auth_dot_principal____client__pb2
from tecton_proto.auth import service__client_pb2 as tecton__proto_dot_auth_dot_service____client__pb2
from tecton_proto.common import aws_credentials__client_pb2 as tecton__proto_dot_common_dot_aws__credentials____client__pb2
from tecton_proto.common import fco_locator__client_pb2 as tecton__proto_dot_common_dot_fco__locator____client__pb2
from tecton_proto.common import id__client_pb2 as tecton__proto_dot_common_dot_id____client__pb2
from tecton_proto.common import spark_schema__client_pb2 as tecton__proto_dot_common_dot_spark__schema____client__pb2
from tecton_proto.data import entity__client_pb2 as tecton__proto_dot_data_dot_entity____client__pb2
from tecton_proto.data import fco__client_pb2 as tecton__proto_dot_data_dot_fco____client__pb2
from tecton_proto.data import feature_service__client_pb2 as tecton__proto_dot_data_dot_feature__service____client__pb2
from tecton_proto.data import feature_view__client_pb2 as tecton__proto_dot_data_dot_feature__view____client__pb2
from tecton_proto.data import freshness_status__client_pb2 as tecton__proto_dot_data_dot_freshness__status____client__pb2
from tecton_proto.data import hive_metastore__client_pb2 as tecton__proto_dot_data_dot_hive__metastore____client__pb2
from tecton_proto.data import internal_spark_cluster_status__client_pb2 as tecton__proto_dot_data_dot_internal__spark__cluster__status____client__pb2
from tecton_proto.data import materialization_status__client_pb2 as tecton__proto_dot_data_dot_materialization__status____client__pb2
from tecton_proto.data import onboarding__client_pb2 as tecton__proto_dot_data_dot_onboarding____client__pb2
from tecton_proto.data import saved_feature_data_frame__client_pb2 as tecton__proto_dot_data_dot_saved__feature__data__frame____client__pb2
from tecton_proto.data import serving_status__client_pb2 as tecton__proto_dot_data_dot_serving__status____client__pb2
from tecton_proto.data import state_update__client_pb2 as tecton__proto_dot_data_dot_state__update____client__pb2
from tecton_proto.data import summary__client_pb2 as tecton__proto_dot_data_dot_summary____client__pb2
from tecton_proto.data import tecton_api_key__client_pb2 as tecton__proto_dot_data_dot_tecton__api__key____client__pb2
from tecton_proto.data import transformation__client_pb2 as tecton__proto_dot_data_dot_transformation____client__pb2
from tecton_proto.data import user__client_pb2 as tecton__proto_dot_data_dot_user____client__pb2
from tecton_proto.data import user_deployment_settings__client_pb2 as tecton__proto_dot_data_dot_user__deployment__settings____client__pb2
from tecton_proto.data import virtual_data_source__client_pb2 as tecton__proto_dot_data_dot_virtual__data__source____client__pb2
from tecton_proto.data import workspace__client_pb2 as tecton__proto_dot_data_dot_workspace____client__pb2
from tecton_proto.dataobs import expectation__client_pb2 as tecton__proto_dot_dataobs_dot_expectation____client__pb2
from tecton_proto.dataobs import metric__client_pb2 as tecton__proto_dot_dataobs_dot_metric____client__pb2
from tecton_proto.dataobs import validation__client_pb2 as tecton__proto_dot_dataobs_dot_validation____client__pb2
from tecton_proto.feature_analytics import feature_analytics__client_pb2 as tecton__proto_dot_feature__analytics_dot_feature__analytics____client__pb2
from tecton_proto.materialization import job_metadata__client_pb2 as tecton__proto_dot_materialization_dot_job__metadata____client__pb2
from tecton_proto.materialization import spark_cluster__client_pb2 as tecton__proto_dot_materialization_dot_spark__cluster____client__pb2
from tecton_proto.validation import validator__client_pb2 as tecton__proto_dot_validation_dot_validator____client__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;tecton_proto/metadataservice/metadata_service__client.proto\x12\x1ctecton_proto.metadataservice\x1a\x1egoogle/protobuf/duration.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a.tecton_proto/amplitude/amplitude__client.proto\x1a\x33tecton_proto/amplitude/client_logging__client.proto\x1a,tecton_proto/args/feature_view__client.proto\x1a,tecton_proto/auditlog/metadata__client.proto\x1a)tecton_proto/auth/principal__client.proto\x1a\'tecton_proto/auth/service__client.proto\x1a\x31tecton_proto/common/aws_credentials__client.proto\x1a-tecton_proto/common/fco_locator__client.proto\x1a$tecton_proto/common/id__client.proto\x1a.tecton_proto/common/spark_schema__client.proto\x1a&tecton_proto/data/entity__client.proto\x1a#tecton_proto/data/fco__client.proto\x1a/tecton_proto/data/feature_service__client.proto\x1a,tecton_proto/data/feature_view__client.proto\x1a\x30tecton_proto/data/freshness_status__client.proto\x1a.tecton_proto/data/hive_metastore__client.proto\x1a=tecton_proto/data/internal_spark_cluster_status__client.proto\x1a\x36tecton_proto/data/materialization_status__client.proto\x1a*tecton_proto/data/onboarding__client.proto\x1a\x38tecton_proto/data/saved_feature_data_frame__client.proto\x1a.tecton_proto/data/serving_status__client.proto\x1a,tecton_proto/data/state_update__client.proto\x1a\'tecton_proto/data/summary__client.proto\x1a.tecton_proto/data/tecton_api_key__client.proto\x1a.tecton_proto/data/transformation__client.proto\x1a$tecton_proto/data/user__client.proto\x1a\x38tecton_proto/data/user_deployment_settings__client.proto\x1a\x33tecton_proto/data/virtual_data_source__client.proto\x1a)tecton_proto/data/workspace__client.proto\x1a.tecton_proto/dataobs/expectation__client.proto\x1a)tecton_proto/dataobs/metric__client.proto\x1a-tecton_proto/dataobs/validation__client.proto\x1a>tecton_proto/feature_analytics/feature_analytics__client.proto\x1a\x37tecton_proto/materialization/job_metadata__client.proto\x1a\x38tecton_proto/materialization/spark_cluster__client.proto\x1a/tecton_proto/validation/validator__client.proto\"\x90\x01\n\nJobsKeySet\x12\x39\n\nupdated_at\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tupdatedAt\x12\x1e\n\ncomparison\x18\x03 \x01(\x03R\ncomparison\x12\'\n\x02id\x18\x02 \x01(\x0b\x32\x17.tecton_proto.common.IdR\x02id\"\xd0\x01\n\x11PaginationRequest\x12\x12\n\x04page\x18\x01 \x01(\rR\x04page\x12\x19\n\x08per_page\x18\x02 \x01(\rR\x07perPage\x12\x19\n\x08sort_key\x18\x03 \x01(\tR\x07sortKey\x12R\n\x0esort_direction\x18\x04 \x01(\x0e\x32+.tecton_proto.metadataservice.SortDirectionR\rsortDirection\x12\x1d\n\npage_token\x18\x05 \x01(\tR\tpageToken\"\xf0\x01\n\x12PaginationResponse\x12\x12\n\x04page\x18\x01 \x01(\rR\x04page\x12\x19\n\x08per_page\x18\x02 \x01(\rR\x07perPage\x12\x14\n\x05total\x18\x03 \x01(\rR\x05total\x12&\n\x0fnext_page_token\x18\x04 \x01(\tR\rnextPageToken\x12\x19\n\x08sort_key\x18\x05 \x01(\tR\x07sortKey\x12R\n\x0esort_direction\x18\x06 \x01(\x0e\x32+.tecton_proto.metadataservice.SortDirectionR\rsortDirection\"\xbd\x01\n\x15ValidationResultToken\x12\x43\n\x0fvalidation_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0evalidationTime\x12\x34\n\tresult_id\x18\x02 \x01(\x0b\x32\x17.tecton_proto.common.IdR\x08resultId\x12)\n\x10\x65xpectation_name\x18\x03 \x01(\tR\x0f\x65xpectationName\"\xd3\x01\n\x18GetFeatureServiceRequest\x12+\n\x11service_reference\x18\x02 \x01(\tR\x10serviceReference\x12\x1c\n\tworkspace\x18\x03 \x01(\tR\tworkspace\x12\'\n\x02id\x18\x04 \x01(\x0b\x32\x17.tecton_proto.common.IdR\x02id\x12\x37\n\x18run_object_version_check\x18\x06 \x01(\x08R\x15runObjectVersionCheckJ\x04\x08\x01\x10\x02J\x04\x08\x05\x10\x06\"a\n\x19GetFeatureServiceResponse\x12\x44\n\rfco_container\x18\x02 \x01(\x0b\x32\x1f.tecton_proto.data.FcoContainerR\x0c\x66\x63oContainer\"<\n\x1cGetAllFeatureServicesRequest\x12\x1c\n\tworkspace\x18\x01 \x01(\tR\tworkspace\"m\n\x1dGetAllFeatureServicesResponse\x12L\n\x10\x66\x65\x61ture_services\x18\x01 \x03(\x0b\x32!.tecton_proto.data.FeatureServiceR\x0f\x66\x65\x61tureServices\"\xc7\x01\n\x1fGetFeatureServiceSummaryRequest\x12G\n\x12\x66\x65\x61ture_service_id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdH\x00R\x10\x66\x65\x61tureServiceId\x12\x32\n\x14\x66\x65\x61ture_service_name\x18\x02 \x01(\tH\x00R\x12\x66\x65\x61tureServiceName\x12\x1c\n\tworkspace\x18\x03 \x01(\tR\tworkspaceB\t\n\x07locator\"\x8c\x01\n GetFeatureServiceSummaryResponse\x12\x43\n\rgeneral_items\x18\x01 \x03(\x0b\x32\x1e.tecton_proto.data.SummaryItemR\x0cgeneralItems\x12#\n\rvariant_names\x18\x03 \x03(\tR\x0cvariantNames\"f\n\"GetVirtualDataSourceSummaryRequest\x12@\n\x0b\x66\x63o_locator\x18\x01 \x01(\x0b\x32\x1f.tecton_proto.common.FcoLocatorR\nfcoLocator\"e\n#GetVirtualDataSourceSummaryResponse\x12>\n\x0b\x66\x63o_summary\x18\x01 \x01(\x0b\x32\x1d.tecton_proto.data.FcoSummaryR\nfcoSummary\"c\n\x1fGetTransformationSummaryRequest\x12@\n\x0b\x66\x63o_locator\x18\x01 \x01(\x0b\x32\x1f.tecton_proto.common.FcoLocatorR\nfcoLocator\"b\n GetTransformationSummaryResponse\x12>\n\x0b\x66\x63o_summary\x18\x01 \x01(\x0b\x32\x1d.tecton_proto.data.FcoSummaryR\nfcoSummary\"[\n\x17GetEntitySummaryRequest\x12@\n\x0b\x66\x63o_locator\x18\x01 \x01(\x0b\x32\x1f.tecton_proto.common.FcoLocatorR\nfcoLocator\"Z\n\x18GetEntitySummaryResponse\x12>\n\x0b\x66\x63o_summary\x18\x01 \x01(\x0b\x32\x1d.tecton_proto.data.FcoSummaryR\nfcoSummary\"\xd9\x01\n\x17GetServingStatusRequest\x12G\n\x12\x66\x65\x61ture_package_id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdH\x00R\x10\x66\x65\x61turePackageId\x12G\n\x12\x66\x65\x61ture_service_id\x18\x02 \x01(\x0b\x32\x17.tecton_proto.common.IdH\x00R\x10\x66\x65\x61tureServiceId\x12\x1c\n\tworkspace\x18\x03 \x01(\tR\tworkspaceB\x0e\n\x0crequest_type\"\xd6\x01\n\x1eGetFVServingStatusForFSRequest\x12\x45\n\x12\x66\x65\x61ture_service_id\x18\x02 \x02(\x0b\x32\x17.tecton_proto.common.IdR\x10\x66\x65\x61tureServiceId\x12\x1c\n\tworkspace\x18\x03 \x01(\tR\tworkspace\x12O\n\npagination\x18\x04 \x01(\x0b\x32/.tecton_proto.metadataservice.PaginationRequestR\npagination\"\xe7\x01\n\x1fGetFVServingStatusForFSResponse\x12r\n\x1b\x66ull_serving_status_summary\x18\x01 \x01(\x0b\x32\x33.tecton_proto.data.FullFeatureServiceServingSummaryR\x18\x66ullServingStatusSummary\x12P\n\npagination\x18\x02 \x01(\x0b\x32\x30.tecton_proto.metadataservice.PaginationResponseR\npagination\"y\n\x18GetServingStatusResponse\x12]\n\x16serving_status_summary\x18\x05 \x01(\x0b\x32\'.tecton_proto.data.ServingStatusSummaryR\x14servingStatusSummary\"=\n\x1dGetAllFeatureFreshnessRequest\x12\x1c\n\tworkspace\x18\x01 \x01(\tR\tworkspace\"s\n\x1eGetAllFeatureFreshnessResponse\x12Q\n\x12\x66reshness_statuses\x18\x01 \x03(\x0b\x32\".tecton_proto.data.FreshnessStatusR\x11\x66reshnessStatuses\"^\n\x1aGetFeatureFreshnessRequest\x12@\n\x0b\x66\x63o_locator\x18\x01 \x01(\x0b\x32\x1f.tecton_proto.common.FcoLocatorR\nfcoLocator\"l\n\x1bGetFeatureFreshnessResponse\x12M\n\x10\x66reshness_status\x18\x01 \x01(\x0b\x32\".tecton_proto.data.FreshnessStatusR\x0f\x66reshnessStatus\"\xaf\x01\n\x1fGetMaterializationStatusRequest\x12\x45\n\x12\x66\x65\x61ture_package_id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdR\x10\x66\x65\x61turePackageId\x12\x1c\n\tworkspace\x18\x03 \x01(\tR\tworkspace\x12\'\n\x0finclude_deleted\x18\x02 \x01(\x08R\x0eincludeDeleted\"\x83\x01\n GetMaterializationStatusResponse\x12_\n\x16materialization_status\x18\x01 \x01(\x0b\x32(.tecton_proto.data.MaterializationStatusR\x15materializationStatus\"V\n2GetAllMaterializationStatusInLiveWorkspacesRequest\x12 \n\x0c\x63ut_off_days\x18\x01 \x01(\x05R\ncutOffDays\"4\n\nCountRange\x12\x14\n\x05start\x18\x01 \x01(\rR\x05start\x12\x10\n\x03\x65nd\x18\x02 \x01(\rR\x03\x65nd\"m\n\rDurationRange\x12/\n\x05start\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationR\x05start\x12+\n\x03\x65nd\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationR\x03\x65nd\"o\n\rDateTimeRange\x12\x30\n\x05start\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x05start\x12,\n\x03\x65nd\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x03\x65nd\"\xac\x07\n\x0eGetJobsRequest\x12\x1e\n\nworkspaces\x18\x01 \x03(\tR\nworkspaces\x12#\n\rfeature_views\x18\x02 \x03(\tR\x0c\x66\x65\x61tureViews\x12I\n\x08statuses\x18\x03 \x03(\x0e\x32-.tecton_proto.data.MaterializationStatusStateR\x08statuses\x12`\n\x16last_task_state_change\x18\x06 \x01(\x0b\x32+.tecton_proto.metadataservice.DateTimeRangeR\x13lastTaskStateChange\x12\x43\n\ttask_type\x18\x04 \x03(\x0e\x32&.tecton_proto.materialization.TaskTypeR\x08taskType\x12K\n\x0cnum_attempts\x18\x05 \x01(\x0b\x32(.tecton_proto.metadataservice.CountRangeR\x0bnumAttempts\x12-\n\x12manually_triggered\x18\x07 \x01(\x08R\x11manuallyTriggered\x12G\n\x08\x64uration\x18\x08 \x01(\x0b\x32+.tecton_proto.metadataservice.DurationRangeR\x08\x64uration\x12Y\n\x12\x66\x65\x61ture_start_time\x18\n \x01(\x0b\x32+.tecton_proto.metadataservice.DateTimeRangeR\x10\x66\x65\x61tureStartTime\x12U\n\x10\x66\x65\x61ture_end_time\x18\x0b \x01(\x0b\x32+.tecton_proto.metadataservice.DateTimeRangeR\x0e\x66\x65\x61tureEndTime\x12O\n$include_update_materialization_flags\x18\x0c \x01(\x08R!includeUpdateMaterializationFlags\x12#\n\rwrites_online\x18\r \x01(\x08R\x0cwritesOnline\x12%\n\x0ewrites_offline\x18\x0e \x01(\x08R\rwritesOffline\x12O\n\npagination\x18\t \x01(\x0b\x32/.tecton_proto.metadataservice.PaginationRequestR\npagination\"j\n\x14GetJobDetailsRequest\x12R\n\x19tecton_managed_attempt_id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdR\x16tectonManagedAttemptId\"\xc5\x01\n FeatureViewMaterializationStatus\x12@\n\x0b\x66\x63o_locator\x18\x01 \x01(\x0b\x32\x1f.tecton_proto.common.FcoLocatorR\nfcoLocator\x12_\n\x16materialization_status\x18\x03 \x01(\x0b\x32(.tecton_proto.data.MaterializationStatusR\x15materializationStatus\"\xb5\x05\n\x10TaskWithAttempts\x12@\n\x0b\x66\x63o_locator\x18\x01 \x01(\x0b\x32\x1f.tecton_proto.common.FcoLocatorR\nfcoLocator\x12K\n\ttaskState\x18\x02 \x01(\x0e\x32-.tecton_proto.data.MaterializationStatusStateR\ttaskState\x12_\n\x16materialization_status\x18\x03 \x01(\x0b\x32(.tecton_proto.data.MaterializationStatusR\x15materializationStatus\x12\x30\n\x07task_id\x18\x04 \x01(\x0b\x32\x17.tecton_proto.common.IdR\x06taskId\x12\x43\n\ttask_type\x18\x08 \x01(\x0e\x32&.tecton_proto.materialization.TaskTypeR\x08taskType\x12-\n\x12manually_triggered\x18\t \x01(\x08R\x11manuallyTriggered\x12O\n\x16last_task_state_change\x18\n \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x13lastTaskStateChange\x12*\n\x11\x66\x65\x61ture_view_name\x18\x05 \x01(\tR\x0f\x66\x65\x61tureViewName\x12H\n\x12\x66\x65\x61ture_start_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x10\x66\x65\x61tureStartTime\x12\x44\n\x10\x66\x65\x61ture_end_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0e\x66\x65\x61tureEndTime\"\x83\x05\n\x12TaskAttemptDetails\x12\x30\n\x07task_id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdR\x06taskId\x12\x43\n\ttask_type\x18\x02 \x01(\x0e\x32&.tecton_proto.materialization.TaskTypeR\x08taskType\x12L\n\ntask_state\x18\x03 \x01(\x0e\x32-.tecton_proto.data.MaterializationStatusStateR\ttaskState\x12V\n\x0e\x61ttempt_status\x18\x04 \x01(\x0b\x32/.tecton_proto.data.MaterializationAttemptStatusR\rattemptStatus\x12P\n\x0brun_details\x18\x05 \x01(\x0b\x32/.tecton_proto.materialization.TectonManagedInfoR\nrunDetails\x12K\n\x0e\x63luster_config\x18\x06 \x01(\x0b\x32$.tecton_proto.args.RiftClusterConfigR\rclusterConfig\x12H\n\x12\x66\x65\x61ture_start_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x10\x66\x65\x61tureStartTime\x12\x44\n\x10\x66\x65\x61ture_end_time\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0e\x66\x65\x61tureEndTime\x12!\n\x0c\x61nyscale_url\x18\t \x01(\tR\x0b\x61nyscaleUrl\"\xc5\x01\n3GetAllMaterializationStatusInLiveWorkspacesResponse\x12\x8d\x01\n#feature_view_materialization_status\x18\x01 \x03(\x0b\x32>.tecton_proto.metadataservice.FeatureViewMaterializationStatusR featureViewMaterializationStatus\"\xc1\x01\n\x0fGetJobsResponse\x12\\\n\x11tasksWithAttempts\x18\x01 \x03(\x0b\x32..tecton_proto.metadataservice.TaskWithAttemptsR\x11tasksWithAttempts\x12P\n\npagination\x18\x02 \x01(\x0b\x32\x30.tecton_proto.metadataservice.PaginationResponseR\npagination\"\xb4\x01\n\x15GetJobDetailsResponse\x12@\n\x0b\x66\x63o_locator\x18\x01 \x01(\x0b\x32\x1f.tecton_proto.common.FcoLocatorR\nfcoLocator\x12Y\n\x0f\x61ttempt_details\x18\x02 \x01(\x0b\x32\x30.tecton_proto.metadataservice.TaskAttemptDetailsR\x0e\x61ttemptDetails\"\xa0\x01\n$ForceRetryMaterializationTaskRequest\x12O\n\x17materialization_task_id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdR\x15materializationTaskId\x12\'\n\x0f\x61llow_overwrite\x18\x02 \x01(\x08R\x0e\x61llowOverwrite\"L\n%ForceRetryMaterializationTaskResponse\x12#\n\rerror_message\x18\x01 \x01(\tR\x0c\x65rrorMessage\"t\n!RestartMaterializationTaskRequest\x12O\n\x17materialization_task_id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdR\x15materializationTaskId\"\xa1\x01\n\"RestartMaterializationTaskResponse\x12#\n\rerror_message\x18\x01 \x01(\tR\x0c\x65rrorMessage\x12V\n\x1bnew_materialization_task_id\x18\x02 \x01(\x0b\x32\x17.tecton_proto.common.IdR\x18newMaterializationTaskId\".\n\x0eGetFcosRequest\x12\x1c\n\tworkspace\x18\x01 \x01(\tR\tworkspace\"W\n\x0fGetFcosResponse\x12\x44\n\rfco_container\x18\x01 \x01(\x0b\x32\x1f.tecton_proto.data.FcoContainerR\x0c\x66\x63oContainer\"a\n\x15GetSparkConfigRequest\x12\x1c\n\tworkspace\x18\x01 \x01(\tR\tworkspace\x12*\n\x11\x66\x65\x61ture_view_name\x18\x02 \x01(\tR\x0f\x66\x65\x61tureViewName\"F\n\x12SparkClusterConfig\x12\x1a\n\x08original\x18\x01 \x01(\tR\x08original\x12\x14\n\x05\x66inal\x18\x02 \x01(\tR\x05\x66inal\"\xc4\x01\n\x16GetSparkConfigResponse\x12S\n\x0c\x62\x61tch_config\x18\x01 \x01(\x0b\x32\x30.tecton_proto.metadataservice.SparkClusterConfigR\x0b\x62\x61tchConfig\x12U\n\rstream_config\x18\x02 \x01(\x0b\x32\x30.tecton_proto.metadataservice.SparkClusterConfigR\x0cstreamConfig\"t\n(GetMetricAndExpectationDefinitionRequest\x12\x1c\n\tworkspace\x18\x01 \x01(\tR\tworkspace\x12*\n\x11\x66\x65\x61ture_view_name\x18\x02 \x01(\tR\x0f\x66\x65\x61tureViewName\"\xe4\x02\n)GetMetricAndExpectationDefinitionResponse\x12\x1c\n\tworkspace\x18\x01 \x01(\tR\tworkspace\x12*\n\x11\x66\x65\x61ture_view_name\x18\x02 \x01(\tR\x0f\x66\x65\x61tureViewName\x12\x36\n\x07metrics\x18\x03 \x03(\x0b\x32\x1c.tecton_proto.dataobs.MetricR\x07metrics\x12[\n\x14\x66\x65\x61ture_expectations\x18\x04 \x03(\x0b\x32(.tecton_proto.dataobs.FeatureExpectationR\x13\x66\x65\x61tureExpectations\x12X\n\x13metric_expectations\x18\x05 \x03(\x0b\x32\'.tecton_proto.dataobs.MetricExpectationR\x12metricExpectations\"\xca\x01\n\x15GetFeatureViewRequest\x12+\n\x11version_specifier\x18\x01 \x01(\tR\x10versionSpecifier\x12\x1c\n\tworkspace\x18\x03 \x01(\tR\tworkspace\x12\'\n\x02id\x18\x04 \x01(\x0b\x32\x17.tecton_proto.common.IdR\x02id\x12\x37\n\x18run_object_version_check\x18\x06 \x01(\x08R\x15runObjectVersionCheckJ\x04\x08\x05\x10\x06\"^\n\x16GetFeatureViewResponse\x12\x44\n\rfco_container\x18\x02 \x01(\x0b\x32\x1f.tecton_proto.data.FcoContainerR\x0c\x66\x63oContainer\"`\n\x1cGetFeatureViewSummaryRequest\x12@\n\x0b\x66\x63o_locator\x18\x01 \x01(\x0b\x32\x1f.tecton_proto.common.FcoLocatorR\nfcoLocator\"_\n\x1dGetFeatureViewSummaryResponse\x12>\n\x0b\x66\x63o_summary\x18\x01 \x01(\x0b\x32\x1d.tecton_proto.data.FcoSummaryR\nfcoSummary\"R\n\x18QueryFeatureViewsRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x1c\n\tworkspace\x18\x03 \x01(\tR\tworkspaceJ\x04\x08\x05\x10\x06\"a\n\x19QueryFeatureViewsResponse\x12\x44\n\rfco_container\x18\x02 \x01(\x0b\x32\x1f.tecton_proto.data.FcoContainerR\x0c\x66\x63oContainer\"{\n4GetMaterializingFeatureViewsInLiveWorkspacesResponse\x12\x43\n\rfeature_views\x18\x01 \x03(\x0b\x32\x1e.tecton_proto.data.FeatureViewR\x0c\x66\x65\x61tureViews\"\xf3\x01\n\x1bGetVirtualDataSourceRequest\x12N\n\x16virtual_data_source_id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdH\x00R\x13virtualDataSourceId\x12\x14\n\x04name\x18\x02 \x01(\tH\x00R\x04name\x12\x1c\n\tworkspace\x18\x03 \x01(\tR\tworkspace\x12\x37\n\x18run_object_version_check\x18\x04 \x01(\x08R\x15runObjectVersionCheckB\x11\n\x0fidentifier_typeJ\x04\x08\x05\x10\x06\"d\n\x1cGetVirtualDataSourceResponse\x12\x44\n\rfco_container\x18\x02 \x01(\x0b\x32\x1f.tecton_proto.data.FcoContainerR\x0c\x66\x63oContainer\"?\n\x1fGetAllVirtualDataSourcesRequest\x12\x1c\n\tworkspace\x18\x01 \x01(\tR\tworkspace\"z\n GetAllVirtualDataSourcesResponse\x12V\n\x14virtual_data_sources\x18\x01 \x03(\x0b\x32$.tecton_proto.data.VirtualDataSourceR\x12virtualDataSources\"\xd0\x01\n\x10GetEntityRequest\x12\x36\n\tentity_id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdH\x00R\x08\x65ntityId\x12\x14\n\x04name\x18\x02 \x01(\tH\x00R\x04name\x12\x1c\n\tworkspace\x18\x03 \x01(\tR\tworkspace\x12\x37\n\x18run_object_version_check\x18\x06 \x01(\x08R\x15runObjectVersionCheckB\x11\n\x0fidentifier_typeJ\x04\x08\x05\x10\x06\"Y\n\x11GetEntityResponse\x12\x44\n\rfco_container\x18\x02 \x01(\x0b\x32\x1f.tecton_proto.data.FcoContainerR\x0c\x66\x63oContainer\"5\n\x15GetAllEntitiesRequest\x12\x1c\n\tworkspace\x18\x01 \x01(\tR\tworkspace\"O\n\x16GetAllEntitiesResponse\x12\x35\n\x08\x65ntities\x18\x01 \x03(\x0b\x32\x19.tecton_proto.data.EntityR\x08\x65ntities\"\xe8\x01\n\x18GetTransformationRequest\x12\x46\n\x11transformation_id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdH\x00R\x10transformationId\x12\x14\n\x04name\x18\x02 \x01(\tH\x00R\x04name\x12\x1c\n\tworkspace\x18\x04 \x01(\tR\tworkspace\x12\x37\n\x18run_object_version_check\x18\x06 \x01(\x08R\x15runObjectVersionCheckB\x11\n\x0fidentifier_typeJ\x04\x08\x05\x10\x06\"g\n\x19GetTransformationResponse\x12\x44\n\rfco_container\x18\x03 \x01(\x0b\x32\x1f.tecton_proto.data.FcoContainerR\x0c\x66\x63oContainerJ\x04\x08\x01\x10\x02\"<\n\x1cGetAllTransformationsRequest\x12\x1c\n\tworkspace\x18\x02 \x01(\tR\tworkspace\"r\n\x1dGetAllTransformationsResponse\x12K\n\x0ftransformations\x18\x02 \x03(\x0b\x32!.tecton_proto.data.TransformationR\x0ftransformationsJ\x04\x08\x01\x10\x02\"\xa2\x01\n\tModelInfo\x12\'\n\x02id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12(\n\x10model_public_uri\x18\x03 \x01(\tR\x0emodelPublicUri\x12.\n\x13metadata_public_uri\x18\x04 \x01(\tR\x11metadataPublicUri\"+\n\x11ListModelsRequest\x12\x16\n\x06\x66ilter\x18\x01 \x01(\tR\x06\x66ilter\"U\n\x12ListModelsResponse\x12?\n\x06models\x18\x01 \x03(\x0b\x32\'.tecton_proto.metadataservice.ModelInfoR\x06models\")\n\x13GetModelInfoRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\"^\n\x14GetModelInfoResponse\x12\x46\n\nmodel_info\x18\x01 \x01(\x0b\x32\'.tecton_proto.metadataservice.ModelInfoR\tmodelInfo\"Z\n\x17\x46indFcoWorkspaceRequest\x12?\n\x0f\x66\x65\x61ture_view_id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdR\rfeatureViewId\"8\n\x18\x46indFcoWorkspaceResponse\x12\x1c\n\tworkspace\x18\x01 \x01(\tR\tworkspace\"z\n\x17IngestClientLogsRequest\x12_\n\x15sdk_method_invocation\x18\x01 \x01(\x0b\x32+.tecton_proto.amplitude.SDKMethodInvocationR\x13sdkMethodInvocation\"v\n\x16IngestAnalyticsRequest\x12>\n\x06\x65vents\x18\x01 \x03(\x0b\x32&.tecton_proto.amplitude.AmplitudeEventR\x06\x65vents\x12\x1c\n\tworkspace\x18\x02 \x01(\tR\tworkspace\"\xbf\x01\n\x15NewStateUpdateRequest\x12?\n\x07request\x18\x01 \x01(\x0b\x32%.tecton_proto.data.StateUpdateRequestR\x07request\x12\x31\n\x15\x62locking_dry_run_mode\x18\x02 \x01(\x08R\x12\x62lockingDryRunMode\x12\x32\n\x15\x65nable_eager_response\x18\x03 \x01(\x08R\x13\x65nableEagerResponse\"\xaa\x02\n\x17NewStateUpdateRequestV2\x12?\n\x07request\x18\x01 \x01(\x0b\x32%.tecton_proto.data.StateUpdateRequestR\x07request\x12\x31\n\x15\x62locking_dry_run_mode\x18\x02 \x01(\x08R\x12\x62lockingDryRunMode\x12\x32\n\x15\x65nable_eager_response\x18\x03 \x01(\x08R\x13\x65nableEagerResponse\x12\x19\n\x08no_color\x18\x04 \x01(\x08R\x07noColor\x12\x1f\n\x0bjson_output\x18\x05 \x01(\x08R\njsonOutput\x12+\n\x11suppress_warnings\x18\x06 \x01(\x08R\x10suppressWarnings\"\xe7\x01\n\x16NewStateUpdateResponse\x12\x32\n\x08state_id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdR\x07stateId\x12:\n\x1asigned_url_for_repo_upload\x18\x02 \x01(\tR\x16signedUrlForRepoUpload\x12]\n\x0e\x65\x61ger_response\x18\x03 \x01(\x0b\x32\x36.tecton_proto.metadataservice.QueryStateUpdateResponseR\reagerResponse\"\xeb\x01\n\x18NewStateUpdateResponseV2\x12\x32\n\x08state_id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdR\x07stateId\x12:\n\x1asigned_url_for_repo_upload\x18\x02 \x01(\tR\x16signedUrlForRepoUpload\x12_\n\x0e\x65\x61ger_response\x18\x03 \x01(\x0b\x32\x38.tecton_proto.metadataservice.QueryStateUpdateResponseV2R\reagerResponse\"k\n\x17QueryStateUpdateRequest\x12\x32\n\x08state_id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdR\x07stateId\x12\x1c\n\tworkspace\x18\x02 \x01(\tR\tworkspace\"\xd6\x01\n\x19QueryStateUpdateRequestV2\x12\x32\n\x08state_id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdR\x07stateId\x12\x1c\n\tworkspace\x18\x02 \x01(\tR\tworkspace\x12\x19\n\x08no_color\x18\x03 \x01(\x08R\x07noColor\x12\x1f\n\x0bjson_output\x18\x04 \x01(\x08R\njsonOutput\x12+\n\x11suppress_warnings\x18\x06 \x01(\x08R\x10suppressWarnings\"\xd4\x02\n\x18QueryStateUpdateResponse\x12\x14\n\x05ready\x18\x01 \x01(\x08R\x05ready\x12\x18\n\x07success\x18\x02 \x01(\x08R\x07success\x12\x14\n\x05\x65rror\x18\x03 \x01(\tR\x05\x65rror\x12\x31\n\x14recreates_suppressed\x18\x07 \x01(\x08R\x13recreatesSuppressed\x12P\n\x11validation_result\x18\x04 \x01(\x0b\x32#.tecton_proto.data.ValidationResultR\x10validationResult\x12\x39\n\ndiff_items\x18\x05 \x03(\x0b\x32\x1a.tecton_proto.data.FcoDiffR\tdiffItems\x12\x32\n\x15latest_status_message\x18\x06 \x01(\tR\x13latestStatusMessage\"\xe9\x02\n\x1aQueryStateUpdateResponseV2\x12\x14\n\x05ready\x18\x01 \x01(\x08R\x05ready\x12\x18\n\x07success\x18\x02 \x01(\x08R\x07success\x12\x14\n\x05\x65rror\x18\x03 \x01(\tR\x05\x65rror\x12\x32\n\x15latest_status_message\x18\x06 \x01(\tR\x13latestStatusMessage\x12R\n\x11validation_errors\x18\x08 \x01(\x0b\x32#.tecton_proto.data.ValidationResultH\x00R\x10validationErrors\x12_\n\x16successful_plan_output\x18\t \x01(\x0b\x32\'.tecton_proto.data.SuccessfulPlanOutputH\x00R\x14successfulPlanOutputB\n\n\x08responseJ\x04\x08\x04\x10\x05J\x04\x08\x05\x10\x06J\x04\x08\x07\x10\x08\"T\n GetStateUpdatePlanSummaryRequest\x12\x30\n\x07plan_id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdR\x06planId\"b\n!GetStateUpdatePlanSummaryResponse\x12=\n\x04plan\x18\x01 \x01(\x0b\x32).tecton_proto.data.StateUpdatePlanSummaryR\x04plan\"p\n\x17\x41pplyStateUpdateRequest\x12\x32\n\x08state_id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdR\x07stateId\x12!\n\napplied_by\x18\x02 \x01(\tB\x02\x18\x01R\tappliedBy\"\x1a\n\x18\x41pplyStateUpdateResponse\"\xb2\x01\n\x12GetConfigsResponse\x12^\n\nkey_values\x18\x01 \x03(\x0b\x32?.tecton_proto.metadataservice.GetConfigsResponse.KeyValuesEntryR\tkeyValues\x1a<\n\x0eKeyValuesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\xc2\x01\n\x1aGetGlobalsForWebUIResponse\x12\x66\n\nkey_values\x18\x01 \x03(\x0b\x32G.tecton_proto.metadataservice.GetGlobalsForWebUIResponse.KeyValuesEntryR\tkeyValues\x1a<\n\x0eKeyValuesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"N\n\x18GetStateUpdateLogRequest\x12\x14\n\x05limit\x18\x01 \x01(\x05R\x05limit\x12\x1c\n\tworkspace\x18\x02 \x01(\tR\tworkspace\"Z\n\x19GetStateUpdateLogResponse\x12=\n\x07\x65ntries\x18\x01 \x03(\x0b\x32#.tecton_proto.data.StateUpdateEntryR\x07\x65ntries\"S\n\x1dGetStateUpdatePlanListRequest\x12\x14\n\x05limit\x18\x01 \x01(\x05R\x05limit\x12\x1c\n\tworkspace\x18\x02 \x01(\tR\tworkspace\"_\n\x1eGetStateUpdatePlanListResponse\x12=\n\x07\x65ntries\x18\x01 \x03(\x0b\x32#.tecton_proto.data.StateUpdateEntryR\x07\x65ntries\"R\n\x15GetRestoreInfoRequest\x12\x1b\n\tcommit_id\x18\x01 \x01(\tR\x08\x63ommitId\x12\x1c\n\tworkspace\x18\x02 \x01(\tR\tworkspace\"\x96\x01\n\x16GetRestoreInfoResponse\x12>\n\x1csigned_url_for_repo_download\x18\x01 \x01(\tR\x18signedUrlForRepoDownload\x12\x1b\n\tcommit_id\x18\x02 \x01(\tR\x08\x63ommitId\x12\x1f\n\x0bsdk_version\x18\x03 \x01(\tR\nsdkVersion\"\xa5\x01\n\x16\x43reateWorkspaceRequest\x12.\n\x0eworkspace_name\x18\x02 \x01(\tB\x07\xea\x99\xbd\x46\x02\x08\x02R\rworkspaceName\x12U\n\x0c\x63\x61pabilities\x18\x03 \x01(\x0b\x32(.tecton_proto.data.WorkspaceCapabilitiesB\x07\xea\x99\xbd\x46\x02\x08\x02R\x0c\x63\x61pabilitiesJ\x04\x08\x01\x10\x02\"?\n\x16\x44\x65leteWorkspaceRequest\x12%\n\tworkspace\x18\x01 \x01(\tB\x07\xea\x99\xbd\x46\x02\x08\x02R\tworkspace\"2\n\x17IntrospectApiKeyRequest\x12\x17\n\x07\x61pi_key\x18\x01 \x01(\tR\x06\x61piKey\"\xcb\x01\n\x18IntrospectApiKeyResponse\x12\'\n\x02id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdR\x02id\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\x12\x1d\n\ncreated_by\x18\x03 \x01(\tR\tcreatedBy\x12\x16\n\x06\x61\x63tive\x18\x04 \x01(\x08R\x06\x61\x63tive\x12\x19\n\x08is_admin\x18\x05 \x01(\x08R\x07isAdmin\x12\x12\n\x04name\x18\x06 \x01(\tR\x04name\"d\n\x13\x43reateApiKeyRequest\x12)\n\x0b\x64\x65scription\x18\x01 \x01(\tB\x07\xea\x99\xbd\x46\x02\x08\x02R\x0b\x64\x65scription\x12\"\n\x08is_admin\x18\x02 \x01(\x08\x42\x07\xea\x99\xbd\x46\x02\x08\x02R\x07isAdmin\"Z\n\x14\x43reateApiKeyResponse\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x02id\x18\x02 \x01(\x0b\x32\x17.tecton_proto.common.IdB\x07\xea\x99\xbd\x46\x02\x08\x02R\x02id\"G\n\x13\x44\x65leteApiKeyRequest\x12\x30\n\x02id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdB\x07\xea\x99\xbd\x46\x02\x08\x02R\x02id\"?\n\x12ListApiKeysRequest\x12)\n\x10include_archived\x18\x01 \x01(\x08R\x0fincludeArchived\"Q\n\x13ListApiKeysResponse\x12:\n\x08\x61pi_keys\x18\x01 \x03(\x0b\x32\x1f.tecton_proto.data.TectonApiKeyR\x07\x61piKeys\"\xf6\x01\n\x0eServiceAccount\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12\x1b\n\tis_active\x18\x04 \x01(\x08R\x08isActive\x12@\n\ncreated_by\x18\x06 \x01(\x0b\x32!.tecton_proto.auth.PrincipalBasicR\tcreatedBy\x12\x39\n\ncreated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAtJ\x04\x08\x05\x10\x06\"e\n\x1b\x43reateServiceAccountRequest\x12\x1b\n\x04name\x18\x01 \x01(\tB\x07\xea\x99\xbd\x46\x02\x08\x02R\x04name\x12)\n\x0b\x64\x65scription\x18\x02 \x01(\tB\x07\xea\x99\xbd\x46\x02\x08\x02R\x0b\x64\x65scription\"\xf9\x01\n\x1c\x43reateServiceAccountResponse\x12\x17\n\x02id\x18\x01 \x01(\tB\x07\xea\x99\xbd\x46\x02\x08\x02R\x02id\x12\x1b\n\x04name\x18\x02 \x01(\tB\x07\xea\x99\xbd\x46\x02\x08\x02R\x04name\x12)\n\x0b\x64\x65scription\x18\x03 \x01(\tB\x07\xea\x99\xbd\x46\x02\x08\x02R\x0b\x64\x65scription\x12$\n\tis_active\x18\x04 \x01(\x08\x42\x07\xea\x99\xbd\x46\x02\x08\x02R\x08isActive\x12\x17\n\x07\x61pi_key\x18\x05 \x01(\tR\x06\x61piKey\x12\x39\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\"E\n\x19GetServiceAccountsRequest\x12\x16\n\x06search\x18\x01 \x01(\tR\x06search\x12\x10\n\x03ids\x18\x02 \x03(\tR\x03ids\"u\n\x1aGetServiceAccountsResponse\x12W\n\x10service_accounts\x18\x01 \x03(\x0b\x32,.tecton_proto.metadataservice.ServiceAccountR\x0fserviceAccounts\"\xa4\x01\n\x1bUpdateServiceAccountRequest\x12\x17\n\x02id\x18\x01 \x01(\tB\x07\xea\x99\xbd\x46\x02\x08\x02R\x02id\x12\x1b\n\x04name\x18\x02 \x01(\tB\x07\xea\x99\xbd\x46\x02\x08\x02R\x04name\x12)\n\x0b\x64\x65scription\x18\x03 \x01(\tB\x07\xea\x99\xbd\x46\x02\x08\x02R\x0b\x64\x65scription\x12$\n\tis_active\x18\x04 \x01(\x08\x42\x07\xea\x99\xbd\x46\x02\x08\x02R\x08isActive\"\xe0\x01\n\x1cUpdateServiceAccountResponse\x12\x17\n\x02id\x18\x01 \x01(\tB\x07\xea\x99\xbd\x46\x02\x08\x02R\x02id\x12\x1b\n\x04name\x18\x02 \x01(\tB\x07\xea\x99\xbd\x46\x02\x08\x02R\x04name\x12)\n\x0b\x64\x65scription\x18\x03 \x01(\tB\x07\xea\x99\xbd\x46\x02\x08\x02R\x0b\x64\x65scription\x12$\n\tis_active\x18\x04 \x01(\x08\x42\x07\xea\x99\xbd\x46\x02\x08\x02R\x08isActive\x12\x39\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\"6\n\x1b\x44\x65leteServiceAccountRequest\x12\x17\n\x02id\x18\x01 \x01(\tB\x07\xea\x99\xbd\x46\x02\x08\x02R\x02id\"\x1e\n\x1c\x44\x65leteServiceAccountResponse\"\x17\n\x15ListWorkspacesRequest\"V\n\x16ListWorkspacesResponse\x12<\n\nworkspaces\x18\x01 \x03(\x0b\x32\x1c.tecton_proto.data.WorkspaceR\nworkspaces\"<\n\x13GetWorkspaceRequest\x12%\n\x0eworkspace_name\x18\x01 \x01(\tR\rworkspaceName\"R\n\x14GetWorkspaceResponse\x12:\n\tworkspace\x18\x01 \x01(\x0b\x32\x1c.tecton_proto.data.WorkspaceR\tworkspace\"\x93\x03\n\"CreateSavedFeatureDataFrameRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x1c\n\tworkspace\x18\x07 \x01(\tR\tworkspace\x12G\n\x12\x66\x65\x61ture_package_id\x18\x02 \x01(\x0b\x32\x17.tecton_proto.common.IdH\x00R\x10\x66\x65\x61turePackageId\x12G\n\x12\x66\x65\x61ture_service_id\x18\x03 \x01(\x0b\x32\x17.tecton_proto.common.IdH\x00R\x10\x66\x65\x61tureServiceId\x12\x31\n\x15join_key_column_names\x18\x04 \x03(\tR\x12joinKeyColumnNames\x12\x32\n\x15timestamp_column_name\x18\x05 \x01(\tR\x13timestampColumnName\x12\x38\n\x06schema\x18\x06 \x01(\x0b\x32 .tecton_proto.common.SparkSchemaR\x06schemaB\x08\n\x06source\"\x87\x01\n#CreateSavedFeatureDataFrameResponse\x12`\n\x17saved_feature_dataframe\x18\x01 \x01(\x0b\x32(.tecton_proto.data.SavedFeatureDataFrameR\x15savedFeatureDataframe\"{\n#ArchiveSavedFeatureDataFrameRequest\x12T\n\x1asaved_feature_dataframe_id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdR\x17savedFeatureDataframeId\"&\n$ArchiveSavedFeatureDataFrameResponse\"\xe7\x01\n\x1fGetSavedFeatureDataFrameRequest\x12\x41\n\x1csaved_feature_dataframe_name\x18\x01 \x01(\tH\x00R\x19savedFeatureDataframeName\x12V\n\x1asaved_feature_dataframe_id\x18\x02 \x01(\x0b\x32\x17.tecton_proto.common.IdH\x00R\x17savedFeatureDataframeId\x12\x1c\n\tworkspace\x18\x03 \x01(\tR\tworkspaceB\x0b\n\treference\"\xa5\x01\n\x1bGetClusterAdminInfoResponse\x12&\n\x0f\x63\x61ller_is_admin\x18\x01 \x01(\x08R\rcallerIsAdmin\x12-\n\x05users\x18\x02 \x03(\x0b\x32\x17.tecton_proto.data.UserR\x05users\x12/\n\x06\x61\x64mins\x18\x03 \x03(\x0b\x32\x17.tecton_proto.data.UserR\x06\x61\x64mins\"D\n\x18\x43reateClusterUserRequest\x12(\n\x0blogin_email\x18\x01 \x01(\tB\x07\xea\x99\xbd\x46\x02\x08\x02R\nloginEmail\"!\n\x19\x43reateClusterUserResponseJ\x04\x08\x01\x10\x02\"<\n\x18\x44\x65leteClusterUserRequest\x12 \n\x07okta_id\x18\x01 \x01(\tB\x07\xea\x99\xbd\x46\x02\x08\x02R\x06oktaId\"!\n\x19\x44\x65leteClusterUserResponseJ\x04\x08\x01\x10\x02\"\x8f\x02\n\x18\x43lusterUserActionRequest\x12 \n\x07okta_id\x18\x01 \x01(\tB\x07\xea\x99\xbd\x46\x02\x08\x02R\x06oktaId\x12\x41\n\x17resend_activation_email\x18\x02 \x01(\x08\x42\x07\xea\x99\xbd\x46\x02\x08\x02H\x00R\x15resendActivationEmail\x12*\n\x0bunlock_user\x18\x03 \x01(\x08\x42\x07\xea\x99\xbd\x46\x02\x08\x02H\x00R\nunlockUser\x12*\n\x0bgrant_admin\x18\x04 \x01(\x08\x42\x07\xea\x99\xbd\x46\x02\x08\x02H\x00R\ngrantAdmin\x12,\n\x0crevoke_admin\x18\x05 \x01(\x08\x42\x07\xea\x99\xbd\x46\x02\x08\x02H\x00R\x0brevokeAdminB\x08\n\x06\x61\x63tion\"!\n\x19\x43lusterUserActionResponseJ\x04\x08\x01\x10\x02\"\x84\x01\n GetSavedFeatureDataFrameResponse\x12`\n\x17saved_feature_dataframe\x18\x01 \x01(\x0b\x32(.tecton_proto.data.SavedFeatureDataFrameR\x15savedFeatureDataframe\"C\n#GetAllSavedFeatureDataFramesRequest\x12\x1c\n\tworkspace\x18\x01 \x01(\tR\tworkspace\"\x8a\x01\n$GetAllSavedFeatureDataFramesResponse\x12\x62\n\x18saved_feature_dataframes\x18\x01 \x03(\x0b\x32(.tecton_proto.data.SavedFeatureDataFrameR\x16savedFeatureDataframes\"\x9c\x01\n\x16IngestDataframeRequest\x12K\n\x15\x66\x65\x61ture_definition_id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdR\x13\x66\x65\x61tureDefinitionId\x12\x17\n\x07\x64\x66_path\x18\x02 \x01(\tR\x06\x64\x66Path\x12\x1c\n\tworkspace\x18\x03 \x01(\tR\tworkspace\"\x19\n\x17IngestDataframeResponse\"o\n GetNewIngestDataframeInfoRequest\x12K\n\x15\x66\x65\x61ture_definition_id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdR\x13\x66\x65\x61tureDefinitionId\"t\n!GetNewIngestDataframeInfoResponse\x12\x17\n\x07\x64\x66_path\x18\x01 \x01(\tR\x06\x64\x66Path\x12\x36\n\x18signed_url_for_df_upload\x18\x02 \x01(\tR\x14signedUrlForDfUpload\"\x88\x01\n!GetUserDeploymentSettingsResponse\x12\x63\n\x18user_deployment_settings\x18\x01 \x01(\x0b\x32).tecton_proto.data.UserDeploymentSettingsR\x16userDeploymentSettings\"\xc5\x01\n#UpdateUserDeploymentSettingsRequest\x12\x63\n\x18user_deployment_settings\x18\x01 \x01(\x0b\x32).tecton_proto.data.UserDeploymentSettingsR\x16userDeploymentSettings\x12\x39\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskR\tfieldMask\"e\n$UpdateUserDeploymentSettingsResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\x12#\n\rerror_message\x18\x02 \x01(\tR\x0c\x65rrorMessage\"n\n%GetInternalSparkClusterStatusResponse\x12\x45\n\x06status\x18\x01 \x01(\x0b\x32-.tecton_proto.data.InternalSparkClusterStatusR\x06status\"k\n\x1cGetDeleteEntitiesInfoRequest\x12K\n\x15\x66\x65\x61ture_definition_id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdR\x13\x66\x65\x61tureDefinitionId\"\xca\x01\n\x1dGetDeleteEntitiesInfoResponse\x12\x17\n\x07\x64\x66_path\x18\x01 \x01(\tR\x06\x64\x66Path\x12\x43\n\x1fsigned_url_for_df_upload_online\x18\x03 \x01(\tR\x1asignedUrlForDfUploadOnline\x12\x45\n signed_url_for_df_upload_offline\x18\x04 \x01(\tR\x1bsignedUrlForDfUploadOfflineJ\x04\x08\x02\x10\x03\"\xbf\x02\n\x15\x44\x65leteEntitiesRequest\x12@\n\x0b\x66\x63o_locator\x18\x01 \x01(\x0b\x32\x1f.tecton_proto.common.FcoLocatorR\nfcoLocator\x12\x33\n\x15online_join_keys_path\x18\x02 \x01(\tH\x00R\x12onlineJoinKeysPath\x12<\n\x1aonline_join_keys_full_path\x18\x06 \x01(\tH\x00R\x16onlineJoinKeysFullPath\x12\x33\n\x16offline_join_keys_path\x18\x03 \x01(\tR\x13offlineJoinKeysPath\x12\x16\n\x06online\x18\x04 \x01(\x08R\x06online\x12\x18\n\x07offline\x18\x05 \x01(\x08R\x07offlineB\n\n\x08location\"1\n\x16\x44\x65leteEntitiesResponse\x12\x17\n\x07job_ids\x18\x01 \x03(\tR\x06jobIds\"\x1c\n\x1aGetFeatureAnalyticsRequest\"\x8b\x01\n\x1bGetFeatureAnalyticsResponse\x12l\n\x11\x66\x65\x61ture_analytics\x18\x01 \x01(\x0b\x32?.tecton_proto.feature_analytics.FeatureSimilarityAnalysisResultR\x10\x66\x65\x61tureAnalytics\"\xfd\x01\n\x16GetHiveMetadataRequest\x12S\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32;.tecton_proto.metadataservice.GetHiveMetadataRequest.ActionR\x06\x61\x63tion\x12\x1a\n\x08\x64\x61tabase\x18\x02 \x01(\tR\x08\x64\x61tabase\x12\x14\n\x05table\x18\x03 \x01(\tR\x05table\"\\\n\x06\x41\x63tion\x12\x19\n\x15\x41\x43TION_LIST_DATABASES\x10\x00\"\x04\x08\x01\x10\x01\"\x04\x08\x02\x10\x02*\x12\x41\x43TION_LIST_TABLES*\x17\x41\x43TION_GET_TABLE_SCHEMA\"\xe1\x01\n\x17GetHiveMetadataResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\x12#\n\rerror_message\x18\x02 \x01(\tR\x0c\x65rrorMessage\x12\x41\n\tdatabases\x18\x03 \x01(\x0b\x32!.tecton_proto.data.ListHiveResultH\x00R\tdatabases\x12.\n\x13\x64\x65\x62ug_error_message\x18\x06 \x01(\tR\x11\x64\x65\x62ugErrorMessageB\x08\n\x06resultJ\x04\x08\x04\x10\x05J\x04\x08\x05\x10\x06\"\x95\x01\n\x17ValidateLocalFcoRequest\x12Y\n\x12validation_request\x18\x01 \x01(\x0b\x32*.tecton_proto.validation.ValidationRequestR\x11validationRequest\x12\x1f\n\x0bsdk_version\x18\x02 \x01(\tR\nsdkVersion\"\x9c\x01\n\x18ValidateLocalFcoResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\x12P\n\x11validation_result\x18\x02 \x01(\x0b\x32#.tecton_proto.data.ValidationResultR\x10validationResult\x12\x14\n\x05\x65rror\x18\x03 \x01(\tR\x05\x65rror\":\n\x1aGetOnboardingStatusRequest\x12\x1c\n\tworkspace\x18\x01 \x01(\tR\tworkspace\"\xc9\x01\n\x1bGetOnboardingStatusResponse\x12N\n\x0esetup_platform\x18\x03 \x01(\x0e\x32\'.tecton_proto.data.OnboardingStatusEnumR\rsetupPlatform\x12T\n\x11\x66inish_onboarding\x18\x02 \x01(\x0e\x32\'.tecton_proto.data.OnboardingStatusEnumR\x10\x66inishOnboardingJ\x04\x08\x01\x10\x02\"\x92\x01\n\"GetDataPlatformSetupStatusResponse\x12&\n\x0esetupCompleted\x18\x01 \x01(\x08R\x0esetupCompleted\x12\x44\n\x05tasks\x18\x02 \x03(\x0b\x32..tecton_proto.data.DataPlatformSetupTaskStatusR\x05tasks\"i\n\x1dGetObservabilityConfigRequest\x12\x1c\n\tworkspace\x18\x01 \x01(\tR\tworkspace\x12*\n\x11\x66\x65\x61ture_view_name\x18\x02 \x01(\tR\x0f\x66\x65\x61tureViewName\"\xa5\x01\n\x1eGetObservabilityConfigResponse\x12\x1c\n\tworkspace\x18\x01 \x01(\tR\tworkspace\x12*\n\x11\x66\x65\x61ture_view_name\x18\x02 \x01(\tR\x0f\x66\x65\x61tureViewName\x12\x39\n\x19is_dataobs_metric_enabled\x18\x03 \x01(\x08R\x16isDataobsMetricEnabled\"\xaf\x02\n\x12QueryMetricRequest\x12\x1c\n\tworkspace\x18\x01 \x01(\tR\tworkspace\x12*\n\x11\x66\x65\x61ture_view_name\x18\x02 \x01(\tR\x0f\x66\x65\x61tureViewName\x12\x41\n\x0bmetric_type\x18\x03 \x01(\x0e\x32 .tecton_proto.dataobs.MetricTypeR\nmetricType\x12\x39\n\nstart_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tstartTime\x12\x35\n\x08\x65nd_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x07\x65ndTime\x12\x1a\n\x05limit\x18\x06 \x01(\x05:\x04\x35\x30\x30\x30R\x05limit\"\xf5\x03\n\x13QueryMetricResponse\x12\x1c\n\tworkspace\x18\x01 \x01(\tR\tworkspace\x12*\n\x11\x66\x65\x61ture_view_name\x18\x02 \x01(\tR\x0f\x66\x65\x61tureViewName\x12\x41\n\x0bmetric_type\x18\x03 \x01(\x0e\x32 .tecton_proto.dataobs.MetricTypeR\nmetricType\x12V\n\x1ametric_data_point_interval\x18\x05 \x01(\x0b\x32\x19.google.protobuf.DurationR\x17metricDataPointInterval\x12H\n\x12\x61ligned_start_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x10\x61lignedStartTime\x12\x44\n\x10\x61ligned_end_time\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0e\x61lignedEndTime\x12\x46\n\x0bmetric_data\x18\x04 \x03(\x0b\x32%.tecton_proto.dataobs.MetricDataPointR\nmetricData\x12!\n\x0c\x63olumn_names\x18\x06 \x03(\tR\x0b\x63olumnNames\"\x80\x04\n!GetFeatureValidationResultRequest\x12\x1c\n\tworkspace\x18\x01 \x01(\tR\tworkspace\x12N\n\x15validation_start_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x13validationStartTime\x12J\n\x13validation_end_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x11validationEndTime\x12\x39\n\x19\x66ilter_feature_view_names\x18\x04 \x03(\tR\x16\x66ilterFeatureViewNames\x12\x38\n\x18\x66ilter_expectation_names\x18\x05 \x03(\tR\x16\x66ilterExpectationNames\x12[\n\x13\x66ilter_result_types\x18\x06 \x03(\x0e\x32+.tecton_proto.dataobs.ExpectationResultEnumR\x11\x66ilterResultTypes\x12O\n\npagination\x18\x07 \x01(\x0b\x32/.tecton_proto.metadataservice.PaginationRequestR\npagination\"\xb9\x01\n\"GetFeatureValidationResultResponse\x12\x41\n\x07results\x18\x02 \x03(\x0b\x32\'.tecton_proto.dataobs.ExpectationResultR\x07results\x12P\n\npagination\x18\x03 \x01(\x0b\x32\x30.tecton_proto.metadataservice.PaginationResponseR\npagination\"\xde\x01\n\"GetFeatureValidationSummaryRequest\x12\x1c\n\tworkspace\x18\x01 \x01(\tR\tworkspace\x12N\n\x15validation_start_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x13validationStartTime\x12J\n\x13validation_end_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x11validationEndTime\"\xba\x02\n#GetFeatureValidationSummaryResponse\x12\x1c\n\tworkspace\x18\x01 \x01(\tR\tworkspace\x12N\n\x15validation_start_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x13validationStartTime\x12J\n\x13validation_end_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x11validationEndTime\x12Y\n\x11workspace_summary\x18\x04 \x01(\x0b\x32,.tecton_proto.dataobs.WorkspaceResultSummaryR\x10workspaceSummary\"6\n\x0eGetUserRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x14\n\x05\x65mail\x18\x02 \x01(\tR\x05\x65mail\"C\n\x0fGetUserResponse\x12\x30\n\x04user\x18\x01 \x01(\x0b\x32\x1c.tecton_proto.auth.UserBasicR\x04user\"\xa1\x01\n\x1e\x46\x65\x61tureServerAutoScalingConfig\x12!\n\x07\x65nabled\x18\x01 \x01(\x08\x42\x07\xea\x99\xbd\x46\x02\x08\x02R\x07\x65nabled\x12-\n\x0emin_node_count\x18\x02 \x01(\rB\x07\xea\x99\xbd\x46\x02\x08\x02R\x0cminNodeCount\x12-\n\x0emax_node_count\x18\x03 \x01(\rB\x07\xea\x99\xbd\x46\x02\x08\x02R\x0cmaxNodeCount\"\x1f\n\x1dGetFeatureServerConfigRequest\"\xa0\x02\n\x1eGetFeatureServerConfigResponse\x12+\n\x0c\x63urrentCount\x18\x01 \x01(\rB\x07\xea\x99\xbd\x46\x02\x08\x02R\x0c\x63urrentCount\x12/\n\x0e\x61vailableCount\x18\x02 \x01(\rB\x07\xea\x99\xbd\x46\x02\x08\x02R\x0e\x61vailableCount\x12+\n\x0c\x64\x65siredCount\x18\x03 \x01(\rB\x07\xea\x99\xbd\x46\x02\x08\x02R\x0c\x64\x65siredCount\x12s\n\x11\x61utoScalingConfig\x18\x04 \x01(\x0b\x32<.tecton_proto.metadataservice.FeatureServerAutoScalingConfigB\x07\xea\x99\xbd\x46\x02\x08\x02R\x11\x61utoScalingConfig\"\xb3\x01\n\x1dSetFeatureServerConfigRequest\x12\x1d\n\x05\x63ount\x18\x01 \x01(\rB\x07\xea\x99\xbd\x46\x02\x08\x02R\x05\x63ount\x12s\n\x11\x61utoScalingConfig\x18\x02 \x01(\x0b\x32<.tecton_proto.metadataservice.FeatureServerAutoScalingConfigB\x07\xea\x99\xbd\x46\x02\x08\x02R\x11\x61utoScalingConfig\"\xb5\x01\n!GetOfflineStoreCredentialsRequest\x12\x41\n\x0f\x66\x65\x61ture_view_id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdH\x00R\rfeatureViewId\x12?\n\x0e\x64\x61ta_source_id\x18\x02 \x01(\x0b\x32\x17.tecton_proto.common.IdH\x00R\x0c\x64\x61taSourceIdB\x0c\n\nidentifier\"[\n\"GetOfflineStoreCredentialsResponse\x12\x35\n\x03\x61ws\x18\x01 \x01(\x0b\x32#.tecton_proto.common.AwsCredentialsR\x03\x61ws*>\n\rSortDirection\x12\x10\n\x0cSORT_UNKNOWN\x10\x00\x12\x0c\n\x08SORT_ASC\x10\x01\x12\r\n\tSORT_DESC\x10\x02\x32\xaa~\n\x0fMetadataService\x12\xb9\x01\n\x11GetFeatureService\x12\x36.tecton_proto.metadataservice.GetFeatureServiceRequest\x1a\x37.tecton_proto.metadataservice.GetFeatureServiceResponse\"3\xa2\xbc\xe6\xc0\x05-\x1a\r\x08\x01\x12\tworkspace*\x1ctecton/workspace#read_config\x12\xc5\x01\n\x15GetAllFeatureServices\x12:.tecton_proto.metadataservice.GetAllFeatureServicesRequest\x1a;.tecton_proto.metadataservice.GetAllFeatureServicesResponse\"3\xa2\xbc\xe6\xc0\x05-\x1a\r\x08\x01\x12\tworkspace*\x1ctecton/workspace#read_config\x12\xdd\x01\n\x18GetFeatureServiceSummary\x12=.tecton_proto.metadataservice.GetFeatureServiceSummaryRequest\x1a>.tecton_proto.metadataservice.GetFeatureServiceSummaryResponse\"B\xa2\xbc\xe6\xc0\x05<\x1a\r\x08\x01\x12\tworkspace*+tecton/workspace#read_materialization_state\x12\xc5\x01\n\x10GetServingStatus\x12\x35.tecton_proto.metadataservice.GetServingStatusRequest\x1a\x36.tecton_proto.metadataservice.GetServingStatusResponse\"B\xa2\xbc\xe6\xc0\x05<\x1a\r\x08\x01\x12\tworkspace*+tecton/workspace#read_materialization_state\x12\xda\x01\n\x17GetFVServingStatusForFS\x12<.tecton_proto.metadataservice.GetFVServingStatusForFSRequest\x1a=.tecton_proto.metadataservice.GetFVServingStatusForFSResponse\"B\xa2\xbc\xe6\xc0\x05<\x1a\r\x08\x01\x12\tworkspace*+tecton/workspace#read_materialization_state\x12\xd7\x01\n\x16GetAllFeatureFreshness\x12;.tecton_proto.metadataservice.GetAllFeatureFreshnessRequest\x1a<.tecton_proto.metadataservice.GetAllFeatureFreshnessResponse\"B\xa2\xbc\xe6\xc0\x05<\x1a\r\x08\x01\x12\tworkspace*+tecton/workspace#read_materialization_state\x12\xda\x01\n\x13GetFeatureFreshness\x12\x38.tecton_proto.metadataservice.GetFeatureFreshnessRequest\x1a\x39.tecton_proto.metadataservice.GetFeatureFreshnessResponse\"N\xa2\xbc\xe6\xc0\x05H\x1a\x19\x08\x01\x12\x15\x66\x63o_locator.workspace*+tecton/workspace#read_materialization_state\x12\xa3\x01\n\x18GetMaterializationStatus\x12=.tecton_proto.metadataservice.GetMaterializationStatusRequest\x1a>.tecton_proto.metadataservice.GetMaterializationStatusResponse\"\x08\xa2\xbc\xe6\xc0\x05\x02@\x01\x12\xdc\x01\n+GetAllMaterializationStatusInLiveWorkspaces\x12P.tecton_proto.metadataservice.GetAllMaterializationStatusInLiveWorkspacesRequest\x1aQ.tecton_proto.metadataservice.GetAllMaterializationStatusInLiveWorkspacesResponse\"\x08\xa2\xbc\xe6\xc0\x05\x02@\x01\x12p\n\x07GetJobs\x12,.tecton_proto.metadataservice.GetJobsRequest\x1a-.tecton_proto.metadataservice.GetJobsResponse\"\x08\xa2\xbc\xe6\xc0\x05\x02@\x01\x12\x82\x01\n\rGetJobDetails\x12\x32.tecton_proto.metadataservice.GetJobDetailsRequest\x1a\x33.tecton_proto.metadataservice.GetJobDetailsResponse\"\x08\xa2\xbc\xe6\xc0\x05\x02@\x01\x12\xb2\x01\n\x1d\x46orceRetryMaterializationTask\x12\x42.tecton_proto.metadataservice.ForceRetryMaterializationTaskRequest\x1a\x43.tecton_proto.metadataservice.ForceRetryMaterializationTaskResponse\"\x08\xa2\xbc\xe6\xc0\x05\x02@\x01\x12\xa9\x01\n\x1aRestartMaterializationTask\x12?.tecton_proto.metadataservice.RestartMaterializationTaskRequest\x1a@.tecton_proto.metadataservice.RestartMaterializationTaskResponse\"\x08\xa2\xbc\xe6\xc0\x05\x02@\x01\x12\xb0\x01\n\x0eGetSparkConfig\x12\x33.tecton_proto.metadataservice.GetSparkConfigRequest\x1a\x34.tecton_proto.metadataservice.GetSparkConfigResponse\"3\xa2\xbc\xe6\xc0\x05-\x1a\r\x08\x01\x12\tworkspace*\x1ctecton/workspace#read_config\x12\xe9\x01\n!GetMetricAndExpectationDefinition\x12\x46.tecton_proto.metadataservice.GetMetricAndExpectationDefinitionRequest\x1aG.tecton_proto.metadataservice.GetMetricAndExpectationDefinitionResponse\"3\xa2\xbc\xe6\xc0\x05-\x1a\r\x08\x01\x12\tworkspace*\x1ctecton/workspace#read_config\x12\xb0\x01\n\x0eGetFeatureView\x12\x33.tecton_proto.metadataservice.GetFeatureViewRequest\x1a\x34.tecton_proto.metadataservice.GetFeatureViewResponse\"3\xa2\xbc\xe6\xc0\x05-\x1a\r\x08\x01\x12\tworkspace*\x1ctecton/workspace#read_config\x12\xa4\x01\n,GetMaterializingFeatureViewsInLiveWorkspaces\x12\x16.google.protobuf.Empty\x1aR.tecton_proto.metadataservice.GetMaterializingFeatureViewsInLiveWorkspacesResponse\"\x08\xa2\xbc\xe6\xc0\x05\x02@\x01\x12\xb9\x01\n\x11QueryFeatureViews\x12\x36.tecton_proto.metadataservice.QueryFeatureViewsRequest\x1a\x37.tecton_proto.metadataservice.QueryFeatureViewsResponse\"3\xa2\xbc\xe6\xc0\x05-\x1a\r\x08\x01\x12\tworkspace*\x1ctecton/workspace#read_config\x12\xe0\x01\n\x15GetFeatureViewSummary\x12:.tecton_proto.metadataservice.GetFeatureViewSummaryRequest\x1a;.tecton_proto.metadataservice.GetFeatureViewSummaryResponse\"N\xa2\xbc\xe6\xc0\x05H\x1a\x19\x08\x01\x12\x15\x66\x63o_locator.workspace*+tecton/workspace#read_materialization_state\x12\xc2\x01\n\x14GetVirtualDataSource\x12\x39.tecton_proto.metadataservice.GetVirtualDataSourceRequest\x1a:.tecton_proto.metadataservice.GetVirtualDataSourceResponse\"3\xa2\xbc\xe6\xc0\x05-\x1a\r\x08\x01\x12\tworkspace*\x1ctecton/workspace#read_config\x12\xce\x01\n\x18GetAllVirtualDataSources\x12=.tecton_proto.metadataservice.GetAllVirtualDataSourcesRequest\x1a>.tecton_proto.metadataservice.GetAllVirtualDataSourcesResponse\"3\xa2\xbc\xe6\xc0\x05-\x1a\r\x08\x01\x12\tworkspace*\x1ctecton/workspace#read_config\x12\x90\x01\n\x10IngestClientLogs\x12\x35.tecton_proto.metadataservice.IngestClientLogsRequest\x1a\x16.google.protobuf.Empty\"-\xa2\xbc\xe6\xc0\x05\'*%tecton/organization#read_organization\x12\x8e\x01\n\x0fIngestAnalytics\x12\x34.tecton_proto.metadataservice.IngestAnalyticsRequest\x1a\x16.google.protobuf.Empty\"-\xa2\xbc\xe6\xc0\x05\'*%tecton/organization#read_organization\x12\xe3\x01\n\x1bGetVirtualDataSourceSummary\x12@.tecton_proto.metadataservice.GetVirtualDataSourceSummaryRequest\x1a\x41.tecton_proto.metadataservice.GetVirtualDataSourceSummaryResponse\"?\xa2\xbc\xe6\xc0\x05\x39\x1a\x19\x08\x01\x12\x15\x66\x63o_locator.workspace*\x1ctecton/workspace#read_config\x12\x9b\x01\n\x07GetFcos\x12,.tecton_proto.metadataservice.GetFcosRequest\x1a-.tecton_proto.metadataservice.GetFcosResponse\"3\xa2\xbc\xe6\xc0\x05-\x1a\r\x08\x01\x12\tworkspace*\x1ctecton/workspace#read_config\x12\xa1\x01\n\tGetEntity\x12..tecton_proto.metadataservice.GetEntityRequest\x1a/.tecton_proto.metadataservice.GetEntityResponse\"3\xa2\xbc\xe6\xc0\x05-\x1a\r\x08\x01\x12\tworkspace*\x1ctecton/workspace#read_config\x12\xb0\x01\n\x0eGetAllEntities\x12\x33.tecton_proto.metadataservice.GetAllEntitiesRequest\x1a\x34.tecton_proto.metadataservice.GetAllEntitiesResponse\"3\xa2\xbc\xe6\xc0\x05-\x1a\r\x08\x01\x12\tworkspace*\x1ctecton/workspace#read_config\x12\xc2\x01\n\x10GetEntitySummary\x12\x35.tecton_proto.metadataservice.GetEntitySummaryRequest\x1a\x36.tecton_proto.metadataservice.GetEntitySummaryResponse\"?\xa2\xbc\xe6\xc0\x05\x39\x1a\x19\x08\x01\x12\x15\x66\x63o_locator.workspace*\x1ctecton/workspace#read_config\x12\xb9\x01\n\x11GetTransformation\x12\x36.tecton_proto.metadataservice.GetTransformationRequest\x1a\x37.tecton_proto.metadataservice.GetTransformationResponse\"3\xa2\xbc\xe6\xc0\x05-\x1a\r\x08\x01\x12\tworkspace*\x1ctecton/workspace#read_config\x12\xc5\x01\n\x15GetAllTransformations\x12:.tecton_proto.metadataservice.GetAllTransformationsRequest\x1a;.tecton_proto.metadataservice.GetAllTransformationsResponse\"3\xa2\xbc\xe6\xc0\x05-\x1a\r\x08\x01\x12\tworkspace*\x1ctecton/workspace#read_config\x12\xda\x01\n\x18GetTransformationSummary\x12=.tecton_proto.metadataservice.GetTransformationSummaryRequest\x1a>.tecton_proto.metadataservice.GetTransformationSummaryResponse\"?\xa2\xbc\xe6\xc0\x05\x39\x1a\x19\x08\x01\x12\x15\x66\x63o_locator.workspace*\x1ctecton/workspace#read_config\x12\xa4\x01\n\x10\x46indFcoWorkspace\x12\x35.tecton_proto.metadataservice.FindFcoWorkspaceRequest\x1a\x36.tecton_proto.metadataservice.FindFcoWorkspaceResponse\"!\xa2\xbc\xe6\xc0\x05\x1b*\x19tecton/platform#read_only\x12\xb8\x01\n\x0eNewStateUpdate\x12\x33.tecton_proto.metadataservice.NewStateUpdateRequest\x1a\x34.tecton_proto.metadataservice.NewStateUpdateResponse\";\xa2\xbc\xe6\xc0\x05\x35\x1a\x15\x08\x01\x12\x11request.workspace*\x1ctecton/workspace#create_plan\x12\xbe\x01\n\x10NewStateUpdateV2\x12\x35.tecton_proto.metadataservice.NewStateUpdateRequestV2\x1a\x36.tecton_proto.metadataservice.NewStateUpdateResponseV2\";\xa2\xbc\xe6\xc0\x05\x35\x1a\x15\x08\x01\x12\x11request.workspace*\x1ctecton/workspace#create_plan\x12\xb8\x01\n\x10ValidateLocalFco\x12\x35.tecton_proto.metadataservice.ValidateLocalFcoRequest\x1a\x36.tecton_proto.metadataservice.ValidateLocalFcoResponse\"5\xa2\xbc\xe6\xc0\x05/*-tecton/organization#validate_notebook_objects\x12\xb6\x01\n\x10QueryStateUpdate\x12\x35.tecton_proto.metadataservice.QueryStateUpdateRequest\x1a\x36.tecton_proto.metadataservice.QueryStateUpdateResponse\"3\xa2\xbc\xe6\xc0\x05-\x1a\r\x08\x01\x12\tworkspace*\x1ctecton/workspace#read_config\x12\xbc\x01\n\x12QueryStateUpdateV2\x12\x37.tecton_proto.metadataservice.QueryStateUpdateRequestV2\x1a\x38.tecton_proto.metadataservice.QueryStateUpdateResponseV2\"3\xa2\xbc\xe6\xc0\x05-\x1a\r\x08\x01\x12\tworkspace*\x1ctecton/workspace#read_config\x12\x8b\x01\n\x10\x41pplyStateUpdate\x12\x35.tecton_proto.metadataservice.ApplyStateUpdateRequest\x1a\x36.tecton_proto.metadataservice.ApplyStateUpdateResponse\"\x08\xa2\xbc\xe6\xc0\x05\x02@\x01\x12\x85\x01\n\nGetConfigs\x12\x16.google.protobuf.Empty\x1a\x30.tecton_proto.metadataservice.GetConfigsResponse\"-\xa2\xbc\xe6\xc0\x05\'*%tecton/organization#read_organization\x12\x95\x01\n\x12GetGlobalsForWebUI\x12\x16.google.protobuf.Empty\x1a\x38.tecton_proto.metadataservice.GetGlobalsForWebUIResponse\"-\xa2\xbc\xe6\xc0\x05\'*%tecton/organization#read_organization\x12g\n\x0fGetLoginConfigs\x12\x16.google.protobuf.Empty\x1a\x30.tecton_proto.metadataservice.GetConfigsResponse\"\n\xa2\xbc\xe6\xc0\x05\x04\x08\x01\x10\x01\x12?\n\x03Nop\x12\x16.google.protobuf.Empty\x1a\x16.google.protobuf.Empty\"\x08\xa2\xbc\xe6\xc0\x05\x02\x10\x01\x12\xa6\x01\n\x19GetStateUpdatePlanSummary\x12>.tecton_proto.metadataservice.GetStateUpdatePlanSummaryRequest\x1a?.tecton_proto.metadataservice.GetStateUpdatePlanSummaryResponse\"\x08\xa2\xbc\xe6\xc0\x05\x02@\x01\x12\xb9\x01\n\x11GetStateUpdateLog\x12\x36.tecton_proto.metadataservice.GetStateUpdateLogRequest\x1a\x37.tecton_proto.metadataservice.GetStateUpdateLogResponse\"3\xa2\xbc\xe6\xc0\x05-\x1a\r\x08\x01\x12\tworkspace*\x1ctecton/workspace#read_config\x12\xc8\x01\n\x16GetStateUpdatePlanList\x12;.tecton_proto.metadataservice.GetStateUpdatePlanListRequest\x1a<.tecton_proto.metadataservice.GetStateUpdatePlanListResponse\"3\xa2\xbc\xe6\xc0\x05-\x1a\r\x08\x01\x12\tworkspace*\x1ctecton/workspace#read_config\x12\xb0\x01\n\x0eGetRestoreInfo\x12\x33.tecton_proto.metadataservice.GetRestoreInfoRequest\x1a\x34.tecton_proto.metadataservice.GetRestoreInfoResponse\"3\xa2\xbc\xe6\xc0\x05-\x1a\r\x08\x01\x12\tworkspace*\x1ctecton/workspace#read_config\x12\x80\x02\n\x0f\x43reateWorkspace\x12\x34.tecton_proto.metadataservice.CreateWorkspaceRequest\x1a\x16.google.protobuf.Empty\"\x9e\x01\xa2\xbc\xe6\xc0\x05&*$tecton/organization#create_workspace\xa2\xbc\xe6\xc0\x05P2N\n\x1b\x63\x61pabilities.materializable\x12\x04true\x1a)tecton/organization#create_workspace_live\xf2\x99\xbd\x46\x17\x08\x01\x12\x10\x63reate_workspace\x1a\x01\x31\x12\xb5\x01\n\x0f\x44\x65leteWorkspace\x12\x34.tecton_proto.metadataservice.DeleteWorkspaceRequest\x1a\x16.google.protobuf.Empty\"T\xa2\xbc\xe6\xc0\x05\x32\x1a\r\x08\x01\x12\tworkspace*!tecton/workspace#delete_workspace\xf2\x99\xbd\x46\x17\x08\x01\x12\x10\x64\x65lete_workspace\x1a\x01\x31\x12\x85\x01\n\x0eListWorkspaces\x12\x33.tecton_proto.metadataservice.ListWorkspacesRequest\x1a\x34.tecton_proto.metadataservice.ListWorkspacesResponse\"\x08\xa2\xbc\xe6\xc0\x05\x02@\x01\x12\xb2\x01\n\x0cGetWorkspace\x12\x31.tecton_proto.metadataservice.GetWorkspaceRequest\x1a\x32.tecton_proto.metadataservice.GetWorkspaceResponse\";\xa2\xbc\xe6\xc0\x05\x35\x1a\x12\x08\x01\x12\x0eworkspace_name*\x1ftecton/workspace#read_workspace\x12\x8b\x01\n\x10IntrospectApiKey\x12\x35.tecton_proto.metadataservice.IntrospectApiKeyRequest\x1a\x36.tecton_proto.metadataservice.IntrospectApiKeyResponse\"\x08\xa2\xbc\xe6\xc0\x05\x02@\x01\x12\xe3\x01\n\x14\x43reateServiceAccount\x12\x39.tecton_proto.metadataservice.CreateServiceAccountRequest\x1a:.tecton_proto.metadataservice.CreateServiceAccountResponse\"T\xa2\xbc\xe6\xc0\x05,**tecton/organization#create_service_account\xf2\x99\xbd\x46\x1d\x08\x01\x12\x16\x63reate_service_account\x1a\x01\x31\x12\x91\x01\n\x12GetServiceAccounts\x12\x37.tecton_proto.metadataservice.GetServiceAccountsRequest\x1a\x38.tecton_proto.metadataservice.GetServiceAccountsResponse\"\x08\xa2\xbc\xe6\xc0\x05\x02@\x01\x12\xee\x01\n\x14UpdateServiceAccount\x12\x39.tecton_proto.metadataservice.UpdateServiceAccountRequest\x1a:.tecton_proto.metadataservice.UpdateServiceAccountResponse\"_\xa2\xbc\xe6\xc0\x05\x37\x1a\x06\x08\x02\x12\x02id*-tecton/service_account#manage_service_account\xf2\x99\xbd\x46\x1d\x08\x01\x12\x16update_service_account\x1a\x01\x31\x12\xee\x01\n\x14\x44\x65leteServiceAccount\x12\x39.tecton_proto.metadataservice.DeleteServiceAccountRequest\x1a:.tecton_proto.metadataservice.DeleteServiceAccountResponse\"_\xa2\xbc\xe6\xc0\x05\x37\x1a\x06\x08\x02\x12\x02id*-tecton/service_account#manage_service_account\xf2\x99\xbd\x46\x1d\x08\x01\x12\x16\x64\x65lete_service_account\x1a\x01\x31\x12\x8e\x02\n\x0c\x43reateApiKey\x12\x31.tecton_proto.metadataservice.CreateApiKeyRequest\x1a\x32.tecton_proto.metadataservice.CreateApiKeyResponse\"\x96\x01\xa2\xbc\xe6\xc0\x05,**tecton/organization#create_service_account\xa2\xbc\xe6\xc0\x05\x44\x32\x42\n\x08is_admin\x12\x04true\x1a\x30tecton/organization#create_service_account_admin\xf2\x99\xbd\x46\x15\x08\x01\x12\x0e\x63reate_api_key\x1a\x01\x31\x12\xb2\x01\n\x0c\x44\x65leteApiKey\x12\x31.tecton_proto.metadataservice.DeleteApiKeyRequest\x1a\x16.google.protobuf.Empty\"W\xa2\xbc\xe6\xc0\x05\x37\x1a\x06\x08\x02\x12\x02id*-tecton/service_account#manage_service_account\xf2\x99\xbd\x46\x15\x08\x01\x12\x0e\x64\x65lete_api_key\x1a\x01\x31\x12|\n\x0bListApiKeys\x12\x30.tecton_proto.metadataservice.ListApiKeysRequest\x1a\x31.tecton_proto.metadataservice.ListApiKeysResponse\"\x08\xa2\xbc\xe6\xc0\x05\x02@\x01\x12\xda\x01\n\x1b\x43reateSavedFeatureDataFrame\x12@.tecton_proto.metadataservice.CreateSavedFeatureDataFrameRequest\x1a\x41.tecton_proto.metadataservice.CreateSavedFeatureDataFrameResponse\"6\xa2\xbc\xe6\xc0\x05\x30\x1a\r\x08\x01\x12\tworkspace*\x1ftecton/workspace#update_dataset\x12\xaf\x01\n\x1c\x41rchiveSavedFeatureDataFrame\x12\x41.tecton_proto.metadataservice.ArchiveSavedFeatureDataFrameRequest\x1a\x42.tecton_proto.metadataservice.ArchiveSavedFeatureDataFrameResponse\"\x08\xa2\xbc\xe6\xc0\x05\x02@\x01\x12\xcf\x01\n\x18GetSavedFeatureDataFrame\x12=.tecton_proto.metadataservice.GetSavedFeatureDataFrameRequest\x1a>.tecton_proto.metadataservice.GetSavedFeatureDataFrameResponse\"4\xa2\xbc\xe6\xc0\x05.\x1a\r\x08\x01\x12\tworkspace*\x1dtecton/workspace#read_dataset\x12\xdb\x01\n\x1cGetAllSavedFeatureDataFrames\x12\x41.tecton_proto.metadataservice.GetAllSavedFeatureDataFramesRequest\x1a\x42.tecton_proto.metadataservice.GetAllSavedFeatureDataFramesResponse\"4\xa2\xbc\xe6\xc0\x05.\x1a\r\x08\x01\x12\tworkspace*\x1dtecton/workspace#read_dataset\x12\xa6\x01\n\x19GetNewIngestDataframeInfo\x12>.tecton_proto.metadataservice.GetNewIngestDataframeInfoRequest\x1a?.tecton_proto.metadataservice.GetNewIngestDataframeInfoResponse\"\x08\xa2\xbc\xe6\xc0\x05\x02@\x01\x12\xb7\x01\n\x0fIngestDataframe\x12\x34.tecton_proto.metadataservice.IngestDataframeRequest\x1a\x35.tecton_proto.metadataservice.IngestDataframeResponse\"7\xa2\xbc\xe6\xc0\x05\x31\x1a\r\x08\x01\x12\tworkspace* tecton/workspace#ingest_features\x12\x97\x01\n\x13GetClusterAdminInfo\x12\x16.google.protobuf.Empty\x1a\x39.tecton_proto.metadataservice.GetClusterAdminInfoResponse\"-\xa2\xbc\xe6\xc0\x05\'*%tecton/organization#read_organization\x12\xcc\x01\n\x11\x43reateClusterUser\x12\x36.tecton_proto.metadataservice.CreateClusterUserRequest\x1a\x37.tecton_proto.metadataservice.CreateClusterUserResponse\"F\xa2\xbc\xe6\xc0\x05!*\x1ftecton/organization#create_user\xf2\x99\xbd\x46\x1a\x08\x01\x12\x13\x63reate_account_user\x1a\x01\x31\x12\xcc\x01\n\x11\x44\x65leteClusterUser\x12\x36.tecton_proto.metadataservice.DeleteClusterUserRequest\x1a\x37.tecton_proto.metadataservice.DeleteClusterUserResponse\"F\xa2\xbc\xe6\xc0\x05!*\x1ftecton/organization#manage_user\xf2\x99\xbd\x46\x1a\x08\x01\x12\x13\x64\x65lete_account_user\x1a\x01\x31\x12\xcc\x01\n\x11\x43lusterUserAction\x12\x36.tecton_proto.metadataservice.ClusterUserActionRequest\x1a\x37.tecton_proto.metadataservice.ClusterUserActionResponse\"F\xa2\xbc\xe6\xc0\x05!*\x1ftecton/organization#manage_user\xf2\x99\xbd\x46\x1a\x08\x01\x12\x13\x61\x63\x63ount_user_action\x1a\x01\x31\x12\xa3\x01\n\x19GetUserDeploymentSettings\x12\x16.google.protobuf.Empty\x1a?.tecton_proto.metadataservice.GetUserDeploymentSettingsResponse\"-\xa2\xbc\xe6\xc0\x05\'*%tecton/organization#read_organization\x12\xdd\x01\n\x1cUpdateUserDeploymentSettings\x12\x41.tecton_proto.metadataservice.UpdateUserDeploymentSettingsRequest\x1a\x42.tecton_proto.metadataservice.UpdateUserDeploymentSettingsResponse\"6\xa2\xbc\xe6\xc0\x05\x30*.tecton/organization#manage_deployment_settings\x12\xab\x01\n\x1dGetInternalSparkClusterStatus\x12\x16.google.protobuf.Empty\x1a\x43.tecton_proto.metadataservice.GetInternalSparkClusterStatusResponse\"-\xa2\xbc\xe6\xc0\x05\'*%tecton/organization#read_organization\x12\x9a\x01\n\x15GetDeleteEntitiesInfo\x12:.tecton_proto.metadataservice.GetDeleteEntitiesInfoRequest\x1a;.tecton_proto.metadataservice.GetDeleteEntitiesInfoResponse\"\x08\xa2\xbc\xe6\xc0\x05\x02@\x01\x12\xc0\x01\n\x0e\x44\x65leteEntities\x12\x33.tecton_proto.metadataservice.DeleteEntitiesRequest\x1a\x34.tecton_proto.metadataservice.DeleteEntitiesResponse\"C\xa2\xbc\xe6\xc0\x05=\x1a\x19\x08\x01\x12\x15\x66\x63o_locator.workspace* tecton/workspace#delete_features\x12\xb9\x01\n\x13GetFeatureAnalytics\x12\x38.tecton_proto.metadataservice.GetFeatureAnalyticsRequest\x1a\x39.tecton_proto.metadataservice.GetFeatureAnalyticsResponse\"-\xa2\xbc\xe6\xc0\x05\'*%tecton/organization#read_organization\x12\xad\x01\n\x0fGetHiveMetadata\x12\x34.tecton_proto.metadataservice.GetHiveMetadataRequest\x1a\x35.tecton_proto.metadataservice.GetHiveMetadataResponse\"-\xa2\xbc\xe6\xc0\x05\'*%tecton/organization#read_organization\x12\xc2\x01\n\x13GetOnboardingStatus\x12\x38.tecton_proto.metadataservice.GetOnboardingStatusRequest\x1a\x39.tecton_proto.metadataservice.GetOnboardingStatusResponse\"6\xa2\xbc\xe6\xc0\x05\x30\x1a\r\x08\x01\x12\tworkspace*\x1ftecton/workspace#read_workspace\x12\xa5\x01\n\x1aGetDataPlatformSetupStatus\x12\x16.google.protobuf.Empty\x1a@.tecton_proto.metadataservice.GetDataPlatformSetupStatusResponse\"-\xa2\xbc\xe6\xc0\x05\'*%tecton/organization#read_organization\x12\xc8\x01\n\x16GetObservabilityConfig\x12;.tecton_proto.metadataservice.GetObservabilityConfigRequest\x1a<.tecton_proto.metadataservice.GetObservabilityConfigResponse\"3\xa2\xbc\xe6\xc0\x05-\x1a\r\x08\x01\x12\tworkspace*\x1ctecton/workspace#read_config\x12\xa7\x01\n\x0bQueryMetric\x12\x30.tecton_proto.metadataservice.QueryMetricRequest\x1a\x31.tecton_proto.metadataservice.QueryMetricResponse\"3\xa2\xbc\xe6\xc0\x05-\x1a\r\x08\x01\x12\tworkspace*\x1ctecton/workspace#read_config\x12\xd7\x01\n\x1bGetFeatureValidationSummary\x12@.tecton_proto.metadataservice.GetFeatureValidationSummaryRequest\x1a\x41.tecton_proto.metadataservice.GetFeatureValidationSummaryResponse\"3\xa2\xbc\xe6\xc0\x05-\x1a\r\x08\x01\x12\tworkspace*\x1ctecton/workspace#read_metric\x12\xd4\x01\n\x1aGetFeatureValidationResult\x12?.tecton_proto.metadataservice.GetFeatureValidationResultRequest\x1a@.tecton_proto.metadataservice.GetFeatureValidationResultResponse\"3\xa2\xbc\xe6\xc0\x05-\x1a\r\x08\x01\x12\tworkspace*\x1ctecton/workspace#read_metric\x12\xc2\x01\n\x16GetFeatureServerConfig\x12;.tecton_proto.metadataservice.GetFeatureServerConfigRequest\x1a<.tecton_proto.metadataservice.GetFeatureServerConfigResponse\"-\xa2\xbc\xe6\xc0\x05\'*%tecton/organization#read_organization\x12\xea\x01\n\x16SetFeatureServerConfig\x12;.tecton_proto.metadataservice.SetFeatureServerConfigRequest\x1a<.tecton_proto.metadataservice.GetFeatureServerConfigResponse\"U\xa2\xbc\xe6\xc0\x05**(tecton/organization#scale_feature_server\xf2\x99\xbd\x46 \x08\x01\x12\x19set_feature_server_config\x1a\x01\x31\x12\x8d\x01\n\x07GetUser\x12,.tecton_proto.metadataservice.GetUserRequest\x1a-.tecton_proto.metadataservice.GetUserResponse\"%\xa2\xbc\xe6\xc0\x05\x1f*\x1dtecton/organization#list_user\x12\xa9\x01\n\x1aGetOfflineStoreCredentials\x12?.tecton_proto.metadataservice.GetOfflineStoreCredentialsRequest\x1a@.tecton_proto.metadataservice.GetOfflineStoreCredentialsResponse\"\x08\xa2\xbc\xe6\xc0\x05\x02@\x01\x12\x9e\x01\n\nListModels\x12/.tecton_proto.metadataservice.ListModelsRequest\x1a\x30.tecton_proto.metadataservice.ListModelsResponse\"-\xa2\xbc\xe6\xc0\x05\'*%tecton/organization#read_organization\x12\xa4\x01\n\x0cGetModelInfo\x12\x31.tecton_proto.metadataservice.GetModelInfoRequest\x1a\x32.tecton_proto.metadataservice.GetModelInfoResponse\"-\xa2\xbc\xe6\xc0\x05\'*%tecton/organization#read_organizationBg\n\x1a\x63om.tecton.metadataserviceB\x14MetadataServiceProtoP\x01Z1github.com/tecton-ai/tecton_proto/metadataservice')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tecton_proto.metadataservice.metadata_service__client_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\032com.tecton.metadataserviceB\024MetadataServiceProtoP\001Z1github.com/tecton-ai/tecton_proto/metadataservice'
  _APPLYSTATEUPDATEREQUEST.fields_by_name['applied_by']._options = None
  _APPLYSTATEUPDATEREQUEST.fields_by_name['applied_by']._serialized_options = b'\030\001'
  _GETCONFIGSRESPONSE_KEYVALUESENTRY._options = None
  _GETCONFIGSRESPONSE_KEYVALUESENTRY._serialized_options = b'8\001'
  _GETGLOBALSFORWEBUIRESPONSE_KEYVALUESENTRY._options = None
  _GETGLOBALSFORWEBUIRESPONSE_KEYVALUESENTRY._serialized_options = b'8\001'
  _CREATEWORKSPACEREQUEST.fields_by_name['workspace_name']._options = None
  _CREATEWORKSPACEREQUEST.fields_by_name['workspace_name']._serialized_options = b'\352\231\275F\002\010\002'
  _CREATEWORKSPACEREQUEST.fields_by_name['capabilities']._options = None
  _CREATEWORKSPACEREQUEST.fields_by_name['capabilities']._serialized_options = b'\352\231\275F\002\010\002'
  _DELETEWORKSPACEREQUEST.fields_by_name['workspace']._options = None
  _DELETEWORKSPACEREQUEST.fields_by_name['workspace']._serialized_options = b'\352\231\275F\002\010\002'
  _CREATEAPIKEYREQUEST.fields_by_name['description']._options = None
  _CREATEAPIKEYREQUEST.fields_by_name['description']._serialized_options = b'\352\231\275F\002\010\002'
  _CREATEAPIKEYREQUEST.fields_by_name['is_admin']._options = None
  _CREATEAPIKEYREQUEST.fields_by_name['is_admin']._serialized_options = b'\352\231\275F\002\010\002'
  _CREATEAPIKEYRESPONSE.fields_by_name['id']._options = None
  _CREATEAPIKEYRESPONSE.fields_by_name['id']._serialized_options = b'\352\231\275F\002\010\002'
  _DELETEAPIKEYREQUEST.fields_by_name['id']._options = None
  _DELETEAPIKEYREQUEST.fields_by_name['id']._serialized_options = b'\352\231\275F\002\010\002'
  _CREATESERVICEACCOUNTREQUEST.fields_by_name['name']._options = None
  _CREATESERVICEACCOUNTREQUEST.fields_by_name['name']._serialized_options = b'\352\231\275F\002\010\002'
  _CREATESERVICEACCOUNTREQUEST.fields_by_name['description']._options = None
  _CREATESERVICEACCOUNTREQUEST.fields_by_name['description']._serialized_options = b'\352\231\275F\002\010\002'
  _CREATESERVICEACCOUNTRESPONSE.fields_by_name['id']._options = None
  _CREATESERVICEACCOUNTRESPONSE.fields_by_name['id']._serialized_options = b'\352\231\275F\002\010\002'
  _CREATESERVICEACCOUNTRESPONSE.fields_by_name['name']._options = None
  _CREATESERVICEACCOUNTRESPONSE.fields_by_name['name']._serialized_options = b'\352\231\275F\002\010\002'
  _CREATESERVICEACCOUNTRESPONSE.fields_by_name['description']._options = None
  _CREATESERVICEACCOUNTRESPONSE.fields_by_name['description']._serialized_options = b'\352\231\275F\002\010\002'
  _CREATESERVICEACCOUNTRESPONSE.fields_by_name['is_active']._options = None
  _CREATESERVICEACCOUNTRESPONSE.fields_by_name['is_active']._serialized_options = b'\352\231\275F\002\010\002'
  _UPDATESERVICEACCOUNTREQUEST.fields_by_name['id']._options = None
  _UPDATESERVICEACCOUNTREQUEST.fields_by_name['id']._serialized_options = b'\352\231\275F\002\010\002'
  _UPDATESERVICEACCOUNTREQUEST.fields_by_name['name']._options = None
  _UPDATESERVICEACCOUNTREQUEST.fields_by_name['name']._serialized_options = b'\352\231\275F\002\010\002'
  _UPDATESERVICEACCOUNTREQUEST.fields_by_name['description']._options = None
  _UPDATESERVICEACCOUNTREQUEST.fields_by_name['description']._serialized_options = b'\352\231\275F\002\010\002'
  _UPDATESERVICEACCOUNTREQUEST.fields_by_name['is_active']._options = None
  _UPDATESERVICEACCOUNTREQUEST.fields_by_name['is_active']._serialized_options = b'\352\231\275F\002\010\002'
  _UPDATESERVICEACCOUNTRESPONSE.fields_by_name['id']._options = None
  _UPDATESERVICEACCOUNTRESPONSE.fields_by_name['id']._serialized_options = b'\352\231\275F\002\010\002'
  _UPDATESERVICEACCOUNTRESPONSE.fields_by_name['name']._options = None
  _UPDATESERVICEACCOUNTRESPONSE.fields_by_name['name']._serialized_options = b'\352\231\275F\002\010\002'
  _UPDATESERVICEACCOUNTRESPONSE.fields_by_name['description']._options = None
  _UPDATESERVICEACCOUNTRESPONSE.fields_by_name['description']._serialized_options = b'\352\231\275F\002\010\002'
  _UPDATESERVICEACCOUNTRESPONSE.fields_by_name['is_active']._options = None
  _UPDATESERVICEACCOUNTRESPONSE.fields_by_name['is_active']._serialized_options = b'\352\231\275F\002\010\002'
  _DELETESERVICEACCOUNTREQUEST.fields_by_name['id']._options = None
  _DELETESERVICEACCOUNTREQUEST.fields_by_name['id']._serialized_options = b'\352\231\275F\002\010\002'
  _CREATECLUSTERUSERREQUEST.fields_by_name['login_email']._options = None
  _CREATECLUSTERUSERREQUEST.fields_by_name['login_email']._serialized_options = b'\352\231\275F\002\010\002'
  _DELETECLUSTERUSERREQUEST.fields_by_name['okta_id']._options = None
  _DELETECLUSTERUSERREQUEST.fields_by_name['okta_id']._serialized_options = b'\352\231\275F\002\010\002'
  _CLUSTERUSERACTIONREQUEST.fields_by_name['okta_id']._options = None
  _CLUSTERUSERACTIONREQUEST.fields_by_name['okta_id']._serialized_options = b'\352\231\275F\002\010\002'
  _CLUSTERUSERACTIONREQUEST.fields_by_name['resend_activation_email']._options = None
  _CLUSTERUSERACTIONREQUEST.fields_by_name['resend_activation_email']._serialized_options = b'\352\231\275F\002\010\002'
  _CLUSTERUSERACTIONREQUEST.fields_by_name['unlock_user']._options = None
  _CLUSTERUSERACTIONREQUEST.fields_by_name['unlock_user']._serialized_options = b'\352\231\275F\002\010\002'
  _CLUSTERUSERACTIONREQUEST.fields_by_name['grant_admin']._options = None
  _CLUSTERUSERACTIONREQUEST.fields_by_name['grant_admin']._serialized_options = b'\352\231\275F\002\010\002'
  _CLUSTERUSERACTIONREQUEST.fields_by_name['revoke_admin']._options = None
  _CLUSTERUSERACTIONREQUEST.fields_by_name['revoke_admin']._serialized_options = b'\352\231\275F\002\010\002'
  _FEATURESERVERAUTOSCALINGCONFIG.fields_by_name['enabled']._options = None
  _FEATURESERVERAUTOSCALINGCONFIG.fields_by_name['enabled']._serialized_options = b'\352\231\275F\002\010\002'
  _FEATURESERVERAUTOSCALINGCONFIG.fields_by_name['min_node_count']._options = None
  _FEATURESERVERAUTOSCALINGCONFIG.fields_by_name['min_node_count']._serialized_options = b'\352\231\275F\002\010\002'
  _FEATURESERVERAUTOSCALINGCONFIG.fields_by_name['max_node_count']._options = None
  _FEATURESERVERAUTOSCALINGCONFIG.fields_by_name['max_node_count']._serialized_options = b'\352\231\275F\002\010\002'
  _GETFEATURESERVERCONFIGRESPONSE.fields_by_name['currentCount']._options = None
  _GETFEATURESERVERCONFIGRESPONSE.fields_by_name['currentCount']._serialized_options = b'\352\231\275F\002\010\002'
  _GETFEATURESERVERCONFIGRESPONSE.fields_by_name['availableCount']._options = None
  _GETFEATURESERVERCONFIGRESPONSE.fields_by_name['availableCount']._serialized_options = b'\352\231\275F\002\010\002'
  _GETFEATURESERVERCONFIGRESPONSE.fields_by_name['desiredCount']._options = None
  _GETFEATURESERVERCONFIGRESPONSE.fields_by_name['desiredCount']._serialized_options = b'\352\231\275F\002\010\002'
  _GETFEATURESERVERCONFIGRESPONSE.fields_by_name['autoScalingConfig']._options = None
  _GETFEATURESERVERCONFIGRESPONSE.fields_by_name['autoScalingConfig']._serialized_options = b'\352\231\275F\002\010\002'
  _SETFEATURESERVERCONFIGREQUEST.fields_by_name['count']._options = None
  _SETFEATURESERVERCONFIGREQUEST.fields_by_name['count']._serialized_options = b'\352\231\275F\002\010\002'
  _SETFEATURESERVERCONFIGREQUEST.fields_by_name['autoScalingConfig']._options = None
  _SETFEATURESERVERCONFIGREQUEST.fields_by_name['autoScalingConfig']._serialized_options = b'\352\231\275F\002\010\002'
  _METADATASERVICE.methods_by_name['GetFeatureService']._options = None
  _METADATASERVICE.methods_by_name['GetFeatureService']._serialized_options = b'\242\274\346\300\005-\032\r\010\001\022\tworkspace*\034tecton/workspace#read_config'
  _METADATASERVICE.methods_by_name['GetAllFeatureServices']._options = None
  _METADATASERVICE.methods_by_name['GetAllFeatureServices']._serialized_options = b'\242\274\346\300\005-\032\r\010\001\022\tworkspace*\034tecton/workspace#read_config'
  _METADATASERVICE.methods_by_name['GetFeatureServiceSummary']._options = None
  _METADATASERVICE.methods_by_name['GetFeatureServiceSummary']._serialized_options = b'\242\274\346\300\005<\032\r\010\001\022\tworkspace*+tecton/workspace#read_materialization_state'
  _METADATASERVICE.methods_by_name['GetServingStatus']._options = None
  _METADATASERVICE.methods_by_name['GetServingStatus']._serialized_options = b'\242\274\346\300\005<\032\r\010\001\022\tworkspace*+tecton/workspace#read_materialization_state'
  _METADATASERVICE.methods_by_name['GetFVServingStatusForFS']._options = None
  _METADATASERVICE.methods_by_name['GetFVServingStatusForFS']._serialized_options = b'\242\274\346\300\005<\032\r\010\001\022\tworkspace*+tecton/workspace#read_materialization_state'
  _METADATASERVICE.methods_by_name['GetAllFeatureFreshness']._options = None
  _METADATASERVICE.methods_by_name['GetAllFeatureFreshness']._serialized_options = b'\242\274\346\300\005<\032\r\010\001\022\tworkspace*+tecton/workspace#read_materialization_state'
  _METADATASERVICE.methods_by_name['GetFeatureFreshness']._options = None
  _METADATASERVICE.methods_by_name['GetFeatureFreshness']._serialized_options = b'\242\274\346\300\005H\032\031\010\001\022\025fco_locator.workspace*+tecton/workspace#read_materialization_state'
  _METADATASERVICE.methods_by_name['GetMaterializationStatus']._options = None
  _METADATASERVICE.methods_by_name['GetMaterializationStatus']._serialized_options = b'\242\274\346\300\005\002@\001'
  _METADATASERVICE.methods_by_name['GetAllMaterializationStatusInLiveWorkspaces']._options = None
  _METADATASERVICE.methods_by_name['GetAllMaterializationStatusInLiveWorkspaces']._serialized_options = b'\242\274\346\300\005\002@\001'
  _METADATASERVICE.methods_by_name['GetJobs']._options = None
  _METADATASERVICE.methods_by_name['GetJobs']._serialized_options = b'\242\274\346\300\005\002@\001'
  _METADATASERVICE.methods_by_name['GetJobDetails']._options = None
  _METADATASERVICE.methods_by_name['GetJobDetails']._serialized_options = b'\242\274\346\300\005\002@\001'
  _METADATASERVICE.methods_by_name['ForceRetryMaterializationTask']._options = None
  _METADATASERVICE.methods_by_name['ForceRetryMaterializationTask']._serialized_options = b'\242\274\346\300\005\002@\001'
  _METADATASERVICE.methods_by_name['RestartMaterializationTask']._options = None
  _METADATASERVICE.methods_by_name['RestartMaterializationTask']._serialized_options = b'\242\274\346\300\005\002@\001'
  _METADATASERVICE.methods_by_name['GetSparkConfig']._options = None
  _METADATASERVICE.methods_by_name['GetSparkConfig']._serialized_options = b'\242\274\346\300\005-\032\r\010\001\022\tworkspace*\034tecton/workspace#read_config'
  _METADATASERVICE.methods_by_name['GetMetricAndExpectationDefinition']._options = None
  _METADATASERVICE.methods_by_name['GetMetricAndExpectationDefinition']._serialized_options = b'\242\274\346\300\005-\032\r\010\001\022\tworkspace*\034tecton/workspace#read_config'
  _METADATASERVICE.methods_by_name['GetFeatureView']._options = None
  _METADATASERVICE.methods_by_name['GetFeatureView']._serialized_options = b'\242\274\346\300\005-\032\r\010\001\022\tworkspace*\034tecton/workspace#read_config'
  _METADATASERVICE.methods_by_name['GetMaterializingFeatureViewsInLiveWorkspaces']._options = None
  _METADATASERVICE.methods_by_name['GetMaterializingFeatureViewsInLiveWorkspaces']._serialized_options = b'\242\274\346\300\005\002@\001'
  _METADATASERVICE.methods_by_name['QueryFeatureViews']._options = None
  _METADATASERVICE.methods_by_name['QueryFeatureViews']._serialized_options = b'\242\274\346\300\005-\032\r\010\001\022\tworkspace*\034tecton/workspace#read_config'
  _METADATASERVICE.methods_by_name['GetFeatureViewSummary']._options = None
  _METADATASERVICE.methods_by_name['GetFeatureViewSummary']._serialized_options = b'\242\274\346\300\005H\032\031\010\001\022\025fco_locator.workspace*+tecton/workspace#read_materialization_state'
  _METADATASERVICE.methods_by_name['GetVirtualDataSource']._options = None
  _METADATASERVICE.methods_by_name['GetVirtualDataSource']._serialized_options = b'\242\274\346\300\005-\032\r\010\001\022\tworkspace*\034tecton/workspace#read_config'
  _METADATASERVICE.methods_by_name['GetAllVirtualDataSources']._options = None
  _METADATASERVICE.methods_by_name['GetAllVirtualDataSources']._serialized_options = b'\242\274\346\300\005-\032\r\010\001\022\tworkspace*\034tecton/workspace#read_config'
  _METADATASERVICE.methods_by_name['IngestClientLogs']._options = None
  _METADATASERVICE.methods_by_name['IngestClientLogs']._serialized_options = b'\242\274\346\300\005\'*%tecton/organization#read_organization'
  _METADATASERVICE.methods_by_name['IngestAnalytics']._options = None
  _METADATASERVICE.methods_by_name['IngestAnalytics']._serialized_options = b'\242\274\346\300\005\'*%tecton/organization#read_organization'
  _METADATASERVICE.methods_by_name['GetVirtualDataSourceSummary']._options = None
  _METADATASERVICE.methods_by_name['GetVirtualDataSourceSummary']._serialized_options = b'\242\274\346\300\0059\032\031\010\001\022\025fco_locator.workspace*\034tecton/workspace#read_config'
  _METADATASERVICE.methods_by_name['GetFcos']._options = None
  _METADATASERVICE.methods_by_name['GetFcos']._serialized_options = b'\242\274\346\300\005-\032\r\010\001\022\tworkspace*\034tecton/workspace#read_config'
  _METADATASERVICE.methods_by_name['GetEntity']._options = None
  _METADATASERVICE.methods_by_name['GetEntity']._serialized_options = b'\242\274\346\300\005-\032\r\010\001\022\tworkspace*\034tecton/workspace#read_config'
  _METADATASERVICE.methods_by_name['GetAllEntities']._options = None
  _METADATASERVICE.methods_by_name['GetAllEntities']._serialized_options = b'\242\274\346\300\005-\032\r\010\001\022\tworkspace*\034tecton/workspace#read_config'
  _METADATASERVICE.methods_by_name['GetEntitySummary']._options = None
  _METADATASERVICE.methods_by_name['GetEntitySummary']._serialized_options = b'\242\274\346\300\0059\032\031\010\001\022\025fco_locator.workspace*\034tecton/workspace#read_config'
  _METADATASERVICE.methods_by_name['GetTransformation']._options = None
  _METADATASERVICE.methods_by_name['GetTransformation']._serialized_options = b'\242\274\346\300\005-\032\r\010\001\022\tworkspace*\034tecton/workspace#read_config'
  _METADATASERVICE.methods_by_name['GetAllTransformations']._options = None
  _METADATASERVICE.methods_by_name['GetAllTransformations']._serialized_options = b'\242\274\346\300\005-\032\r\010\001\022\tworkspace*\034tecton/workspace#read_config'
  _METADATASERVICE.methods_by_name['GetTransformationSummary']._options = None
  _METADATASERVICE.methods_by_name['GetTransformationSummary']._serialized_options = b'\242\274\346\300\0059\032\031\010\001\022\025fco_locator.workspace*\034tecton/workspace#read_config'
  _METADATASERVICE.methods_by_name['FindFcoWorkspace']._options = None
  _METADATASERVICE.methods_by_name['FindFcoWorkspace']._serialized_options = b'\242\274\346\300\005\033*\031tecton/platform#read_only'
  _METADATASERVICE.methods_by_name['NewStateUpdate']._options = None
  _METADATASERVICE.methods_by_name['NewStateUpdate']._serialized_options = b'\242\274\346\300\0055\032\025\010\001\022\021request.workspace*\034tecton/workspace#create_plan'
  _METADATASERVICE.methods_by_name['NewStateUpdateV2']._options = None
  _METADATASERVICE.methods_by_name['NewStateUpdateV2']._serialized_options = b'\242\274\346\300\0055\032\025\010\001\022\021request.workspace*\034tecton/workspace#create_plan'
  _METADATASERVICE.methods_by_name['ValidateLocalFco']._options = None
  _METADATASERVICE.methods_by_name['ValidateLocalFco']._serialized_options = b'\242\274\346\300\005/*-tecton/organization#validate_notebook_objects'
  _METADATASERVICE.methods_by_name['QueryStateUpdate']._options = None
  _METADATASERVICE.methods_by_name['QueryStateUpdate']._serialized_options = b'\242\274\346\300\005-\032\r\010\001\022\tworkspace*\034tecton/workspace#read_config'
  _METADATASERVICE.methods_by_name['QueryStateUpdateV2']._options = None
  _METADATASERVICE.methods_by_name['QueryStateUpdateV2']._serialized_options = b'\242\274\346\300\005-\032\r\010\001\022\tworkspace*\034tecton/workspace#read_config'
  _METADATASERVICE.methods_by_name['ApplyStateUpdate']._options = None
  _METADATASERVICE.methods_by_name['ApplyStateUpdate']._serialized_options = b'\242\274\346\300\005\002@\001'
  _METADATASERVICE.methods_by_name['GetConfigs']._options = None
  _METADATASERVICE.methods_by_name['GetConfigs']._serialized_options = b'\242\274\346\300\005\'*%tecton/organization#read_organization'
  _METADATASERVICE.methods_by_name['GetGlobalsForWebUI']._options = None
  _METADATASERVICE.methods_by_name['GetGlobalsForWebUI']._serialized_options = b'\242\274\346\300\005\'*%tecton/organization#read_organization'
  _METADATASERVICE.methods_by_name['GetLoginConfigs']._options = None
  _METADATASERVICE.methods_by_name['GetLoginConfigs']._serialized_options = b'\242\274\346\300\005\004\010\001\020\001'
  _METADATASERVICE.methods_by_name['Nop']._options = None
  _METADATASERVICE.methods_by_name['Nop']._serialized_options = b'\242\274\346\300\005\002\020\001'
  _METADATASERVICE.methods_by_name['GetStateUpdatePlanSummary']._options = None
  _METADATASERVICE.methods_by_name['GetStateUpdatePlanSummary']._serialized_options = b'\242\274\346\300\005\002@\001'
  _METADATASERVICE.methods_by_name['GetStateUpdateLog']._options = None
  _METADATASERVICE.methods_by_name['GetStateUpdateLog']._serialized_options = b'\242\274\346\300\005-\032\r\010\001\022\tworkspace*\034tecton/workspace#read_config'
  _METADATASERVICE.methods_by_name['GetStateUpdatePlanList']._options = None
  _METADATASERVICE.methods_by_name['GetStateUpdatePlanList']._serialized_options = b'\242\274\346\300\005-\032\r\010\001\022\tworkspace*\034tecton/workspace#read_config'
  _METADATASERVICE.methods_by_name['GetRestoreInfo']._options = None
  _METADATASERVICE.methods_by_name['GetRestoreInfo']._serialized_options = b'\242\274\346\300\005-\032\r\010\001\022\tworkspace*\034tecton/workspace#read_config'
  _METADATASERVICE.methods_by_name['CreateWorkspace']._options = None
  _METADATASERVICE.methods_by_name['CreateWorkspace']._serialized_options = b'\242\274\346\300\005&*$tecton/organization#create_workspace\242\274\346\300\005P2N\n\033capabilities.materializable\022\004true\032)tecton/organization#create_workspace_live\362\231\275F\027\010\001\022\020create_workspace\032\0011'
  _METADATASERVICE.methods_by_name['DeleteWorkspace']._options = None
  _METADATASERVICE.methods_by_name['DeleteWorkspace']._serialized_options = b'\242\274\346\300\0052\032\r\010\001\022\tworkspace*!tecton/workspace#delete_workspace\362\231\275F\027\010\001\022\020delete_workspace\032\0011'
  _METADATASERVICE.methods_by_name['ListWorkspaces']._options = None
  _METADATASERVICE.methods_by_name['ListWorkspaces']._serialized_options = b'\242\274\346\300\005\002@\001'
  _METADATASERVICE.methods_by_name['GetWorkspace']._options = None
  _METADATASERVICE.methods_by_name['GetWorkspace']._serialized_options = b'\242\274\346\300\0055\032\022\010\001\022\016workspace_name*\037tecton/workspace#read_workspace'
  _METADATASERVICE.methods_by_name['IntrospectApiKey']._options = None
  _METADATASERVICE.methods_by_name['IntrospectApiKey']._serialized_options = b'\242\274\346\300\005\002@\001'
  _METADATASERVICE.methods_by_name['CreateServiceAccount']._options = None
  _METADATASERVICE.methods_by_name['CreateServiceAccount']._serialized_options = b'\242\274\346\300\005,**tecton/organization#create_service_account\362\231\275F\035\010\001\022\026create_service_account\032\0011'
  _METADATASERVICE.methods_by_name['GetServiceAccounts']._options = None
  _METADATASERVICE.methods_by_name['GetServiceAccounts']._serialized_options = b'\242\274\346\300\005\002@\001'
  _METADATASERVICE.methods_by_name['UpdateServiceAccount']._options = None
  _METADATASERVICE.methods_by_name['UpdateServiceAccount']._serialized_options = b'\242\274\346\300\0057\032\006\010\002\022\002id*-tecton/service_account#manage_service_account\362\231\275F\035\010\001\022\026update_service_account\032\0011'
  _METADATASERVICE.methods_by_name['DeleteServiceAccount']._options = None
  _METADATASERVICE.methods_by_name['DeleteServiceAccount']._serialized_options = b'\242\274\346\300\0057\032\006\010\002\022\002id*-tecton/service_account#manage_service_account\362\231\275F\035\010\001\022\026delete_service_account\032\0011'
  _METADATASERVICE.methods_by_name['CreateApiKey']._options = None
  _METADATASERVICE.methods_by_name['CreateApiKey']._serialized_options = b'\242\274\346\300\005,**tecton/organization#create_service_account\242\274\346\300\005D2B\n\010is_admin\022\004true\0320tecton/organization#create_service_account_admin\362\231\275F\025\010\001\022\016create_api_key\032\0011'
  _METADATASERVICE.methods_by_name['DeleteApiKey']._options = None
  _METADATASERVICE.methods_by_name['DeleteApiKey']._serialized_options = b'\242\274\346\300\0057\032\006\010\002\022\002id*-tecton/service_account#manage_service_account\362\231\275F\025\010\001\022\016delete_api_key\032\0011'
  _METADATASERVICE.methods_by_name['ListApiKeys']._options = None
  _METADATASERVICE.methods_by_name['ListApiKeys']._serialized_options = b'\242\274\346\300\005\002@\001'
  _METADATASERVICE.methods_by_name['CreateSavedFeatureDataFrame']._options = None
  _METADATASERVICE.methods_by_name['CreateSavedFeatureDataFrame']._serialized_options = b'\242\274\346\300\0050\032\r\010\001\022\tworkspace*\037tecton/workspace#update_dataset'
  _METADATASERVICE.methods_by_name['ArchiveSavedFeatureDataFrame']._options = None
  _METADATASERVICE.methods_by_name['ArchiveSavedFeatureDataFrame']._serialized_options = b'\242\274\346\300\005\002@\001'
  _METADATASERVICE.methods_by_name['GetSavedFeatureDataFrame']._options = None
  _METADATASERVICE.methods_by_name['GetSavedFeatureDataFrame']._serialized_options = b'\242\274\346\300\005.\032\r\010\001\022\tworkspace*\035tecton/workspace#read_dataset'
  _METADATASERVICE.methods_by_name['GetAllSavedFeatureDataFrames']._options = None
  _METADATASERVICE.methods_by_name['GetAllSavedFeatureDataFrames']._serialized_options = b'\242\274\346\300\005.\032\r\010\001\022\tworkspace*\035tecton/workspace#read_dataset'
  _METADATASERVICE.methods_by_name['GetNewIngestDataframeInfo']._options = None
  _METADATASERVICE.methods_by_name['GetNewIngestDataframeInfo']._serialized_options = b'\242\274\346\300\005\002@\001'
  _METADATASERVICE.methods_by_name['IngestDataframe']._options = None
  _METADATASERVICE.methods_by_name['IngestDataframe']._serialized_options = b'\242\274\346\300\0051\032\r\010\001\022\tworkspace* tecton/workspace#ingest_features'
  _METADATASERVICE.methods_by_name['GetClusterAdminInfo']._options = None
  _METADATASERVICE.methods_by_name['GetClusterAdminInfo']._serialized_options = b'\242\274\346\300\005\'*%tecton/organization#read_organization'
  _METADATASERVICE.methods_by_name['CreateClusterUser']._options = None
  _METADATASERVICE.methods_by_name['CreateClusterUser']._serialized_options = b'\242\274\346\300\005!*\037tecton/organization#create_user\362\231\275F\032\010\001\022\023create_account_user\032\0011'
  _METADATASERVICE.methods_by_name['DeleteClusterUser']._options = None
  _METADATASERVICE.methods_by_name['DeleteClusterUser']._serialized_options = b'\242\274\346\300\005!*\037tecton/organization#manage_user\362\231\275F\032\010\001\022\023delete_account_user\032\0011'
  _METADATASERVICE.methods_by_name['ClusterUserAction']._options = None
  _METADATASERVICE.methods_by_name['ClusterUserAction']._serialized_options = b'\242\274\346\300\005!*\037tecton/organization#manage_user\362\231\275F\032\010\001\022\023account_user_action\032\0011'
  _METADATASERVICE.methods_by_name['GetUserDeploymentSettings']._options = None
  _METADATASERVICE.methods_by_name['GetUserDeploymentSettings']._serialized_options = b'\242\274\346\300\005\'*%tecton/organization#read_organization'
  _METADATASERVICE.methods_by_name['UpdateUserDeploymentSettings']._options = None
  _METADATASERVICE.methods_by_name['UpdateUserDeploymentSettings']._serialized_options = b'\242\274\346\300\0050*.tecton/organization#manage_deployment_settings'
  _METADATASERVICE.methods_by_name['GetInternalSparkClusterStatus']._options = None
  _METADATASERVICE.methods_by_name['GetInternalSparkClusterStatus']._serialized_options = b'\242\274\346\300\005\'*%tecton/organization#read_organization'
  _METADATASERVICE.methods_by_name['GetDeleteEntitiesInfo']._options = None
  _METADATASERVICE.methods_by_name['GetDeleteEntitiesInfo']._serialized_options = b'\242\274\346\300\005\002@\001'
  _METADATASERVICE.methods_by_name['DeleteEntities']._options = None
  _METADATASERVICE.methods_by_name['DeleteEntities']._serialized_options = b'\242\274\346\300\005=\032\031\010\001\022\025fco_locator.workspace* tecton/workspace#delete_features'
  _METADATASERVICE.methods_by_name['GetFeatureAnalytics']._options = None
  _METADATASERVICE.methods_by_name['GetFeatureAnalytics']._serialized_options = b'\242\274\346\300\005\'*%tecton/organization#read_organization'
  _METADATASERVICE.methods_by_name['GetHiveMetadata']._options = None
  _METADATASERVICE.methods_by_name['GetHiveMetadata']._serialized_options = b'\242\274\346\300\005\'*%tecton/organization#read_organization'
  _METADATASERVICE.methods_by_name['GetOnboardingStatus']._options = None
  _METADATASERVICE.methods_by_name['GetOnboardingStatus']._serialized_options = b'\242\274\346\300\0050\032\r\010\001\022\tworkspace*\037tecton/workspace#read_workspace'
  _METADATASERVICE.methods_by_name['GetDataPlatformSetupStatus']._options = None
  _METADATASERVICE.methods_by_name['GetDataPlatformSetupStatus']._serialized_options = b'\242\274\346\300\005\'*%tecton/organization#read_organization'
  _METADATASERVICE.methods_by_name['GetObservabilityConfig']._options = None
  _METADATASERVICE.methods_by_name['GetObservabilityConfig']._serialized_options = b'\242\274\346\300\005-\032\r\010\001\022\tworkspace*\034tecton/workspace#read_config'
  _METADATASERVICE.methods_by_name['QueryMetric']._options = None
  _METADATASERVICE.methods_by_name['QueryMetric']._serialized_options = b'\242\274\346\300\005-\032\r\010\001\022\tworkspace*\034tecton/workspace#read_config'
  _METADATASERVICE.methods_by_name['GetFeatureValidationSummary']._options = None
  _METADATASERVICE.methods_by_name['GetFeatureValidationSummary']._serialized_options = b'\242\274\346\300\005-\032\r\010\001\022\tworkspace*\034tecton/workspace#read_metric'
  _METADATASERVICE.methods_by_name['GetFeatureValidationResult']._options = None
  _METADATASERVICE.methods_by_name['GetFeatureValidationResult']._serialized_options = b'\242\274\346\300\005-\032\r\010\001\022\tworkspace*\034tecton/workspace#read_metric'
  _METADATASERVICE.methods_by_name['GetFeatureServerConfig']._options = None
  _METADATASERVICE.methods_by_name['GetFeatureServerConfig']._serialized_options = b'\242\274\346\300\005\'*%tecton/organization#read_organization'
  _METADATASERVICE.methods_by_name['SetFeatureServerConfig']._options = None
  _METADATASERVICE.methods_by_name['SetFeatureServerConfig']._serialized_options = b'\242\274\346\300\005**(tecton/organization#scale_feature_server\362\231\275F \010\001\022\031set_feature_server_config\032\0011'
  _METADATASERVICE.methods_by_name['GetUser']._options = None
  _METADATASERVICE.methods_by_name['GetUser']._serialized_options = b'\242\274\346\300\005\037*\035tecton/organization#list_user'
  _METADATASERVICE.methods_by_name['GetOfflineStoreCredentials']._options = None
  _METADATASERVICE.methods_by_name['GetOfflineStoreCredentials']._serialized_options = b'\242\274\346\300\005\002@\001'
  _METADATASERVICE.methods_by_name['ListModels']._options = None
  _METADATASERVICE.methods_by_name['ListModels']._serialized_options = b'\242\274\346\300\005\'*%tecton/organization#read_organization'
  _METADATASERVICE.methods_by_name['GetModelInfo']._options = None
  _METADATASERVICE.methods_by_name['GetModelInfo']._serialized_options = b'\242\274\346\300\005\'*%tecton/organization#read_organization'
  _SORTDIRECTION._serialized_start=27988
  _SORTDIRECTION._serialized_end=28050
  _JOBSKEYSET._serialized_start=1963
  _JOBSKEYSET._serialized_end=2107
  _PAGINATIONREQUEST._serialized_start=2110
  _PAGINATIONREQUEST._serialized_end=2318
  _PAGINATIONRESPONSE._serialized_start=2321
  _PAGINATIONRESPONSE._serialized_end=2561
  _VALIDATIONRESULTTOKEN._serialized_start=2564
  _VALIDATIONRESULTTOKEN._serialized_end=2753
  _GETFEATURESERVICEREQUEST._serialized_start=2756
  _GETFEATURESERVICEREQUEST._serialized_end=2967
  _GETFEATURESERVICERESPONSE._serialized_start=2969
  _GETFEATURESERVICERESPONSE._serialized_end=3066
  _GETALLFEATURESERVICESREQUEST._serialized_start=3068
  _GETALLFEATURESERVICESREQUEST._serialized_end=3128
  _GETALLFEATURESERVICESRESPONSE._serialized_start=3130
  _GETALLFEATURESERVICESRESPONSE._serialized_end=3239
  _GETFEATURESERVICESUMMARYREQUEST._serialized_start=3242
  _GETFEATURESERVICESUMMARYREQUEST._serialized_end=3441
  _GETFEATURESERVICESUMMARYRESPONSE._serialized_start=3444
  _GETFEATURESERVICESUMMARYRESPONSE._serialized_end=3584
  _GETVIRTUALDATASOURCESUMMARYREQUEST._serialized_start=3586
  _GETVIRTUALDATASOURCESUMMARYREQUEST._serialized_end=3688
  _GETVIRTUALDATASOURCESUMMARYRESPONSE._serialized_start=3690
  _GETVIRTUALDATASOURCESUMMARYRESPONSE._serialized_end=3791
  _GETTRANSFORMATIONSUMMARYREQUEST._serialized_start=3793
  _GETTRANSFORMATIONSUMMARYREQUEST._serialized_end=3892
  _GETTRANSFORMATIONSUMMARYRESPONSE._serialized_start=3894
  _GETTRANSFORMATIONSUMMARYRESPONSE._serialized_end=3992
  _GETENTITYSUMMARYREQUEST._serialized_start=3994
  _GETENTITYSUMMARYREQUEST._serialized_end=4085
  _GETENTITYSUMMARYRESPONSE._serialized_start=4087
  _GETENTITYSUMMARYRESPONSE._serialized_end=4177
  _GETSERVINGSTATUSREQUEST._serialized_start=4180
  _GETSERVINGSTATUSREQUEST._serialized_end=4397
  _GETFVSERVINGSTATUSFORFSREQUEST._serialized_start=4400
  _GETFVSERVINGSTATUSFORFSREQUEST._serialized_end=4614
  _GETFVSERVINGSTATUSFORFSRESPONSE._serialized_start=4617
  _GETFVSERVINGSTATUSFORFSRESPONSE._serialized_end=4848
  _GETSERVINGSTATUSRESPONSE._serialized_start=4850
  _GETSERVINGSTATUSRESPONSE._serialized_end=4971
  _GETALLFEATUREFRESHNESSREQUEST._serialized_start=4973
  _GETALLFEATUREFRESHNESSREQUEST._serialized_end=5034
  _GETALLFEATUREFRESHNESSRESPONSE._serialized_start=5036
  _GETALLFEATUREFRESHNESSRESPONSE._serialized_end=5151
  _GETFEATUREFRESHNESSREQUEST._serialized_start=5153
  _GETFEATUREFRESHNESSREQUEST._serialized_end=5247
  _GETFEATUREFRESHNESSRESPONSE._serialized_start=5249
  _GETFEATUREFRESHNESSRESPONSE._serialized_end=5357
  _GETMATERIALIZATIONSTATUSREQUEST._serialized_start=5360
  _GETMATERIALIZATIONSTATUSREQUEST._serialized_end=5535
  _GETMATERIALIZATIONSTATUSRESPONSE._serialized_start=5538
  _GETMATERIALIZATIONSTATUSRESPONSE._serialized_end=5669
  _GETALLMATERIALIZATIONSTATUSINLIVEWORKSPACESREQUEST._serialized_start=5671
  _GETALLMATERIALIZATIONSTATUSINLIVEWORKSPACESREQUEST._serialized_end=5757
  _COUNTRANGE._serialized_start=5759
  _COUNTRANGE._serialized_end=5811
  _DURATIONRANGE._serialized_start=5813
  _DURATIONRANGE._serialized_end=5922
  _DATETIMERANGE._serialized_start=5924
  _DATETIMERANGE._serialized_end=6035
  _GETJOBSREQUEST._serialized_start=6038
  _GETJOBSREQUEST._serialized_end=6978
  _GETJOBDETAILSREQUEST._serialized_start=6980
  _GETJOBDETAILSREQUEST._serialized_end=7086
  _FEATUREVIEWMATERIALIZATIONSTATUS._serialized_start=7089
  _FEATUREVIEWMATERIALIZATIONSTATUS._serialized_end=7286
  _TASKWITHATTEMPTS._serialized_start=7289
  _TASKWITHATTEMPTS._serialized_end=7982
  _TASKATTEMPTDETAILS._serialized_start=7985
  _TASKATTEMPTDETAILS._serialized_end=8628
  _GETALLMATERIALIZATIONSTATUSINLIVEWORKSPACESRESPONSE._serialized_start=8631
  _GETALLMATERIALIZATIONSTATUSINLIVEWORKSPACESRESPONSE._serialized_end=8828
  _GETJOBSRESPONSE._serialized_start=8831
  _GETJOBSRESPONSE._serialized_end=9024
  _GETJOBDETAILSRESPONSE._serialized_start=9027
  _GETJOBDETAILSRESPONSE._serialized_end=9207
  _FORCERETRYMATERIALIZATIONTASKREQUEST._serialized_start=9210
  _FORCERETRYMATERIALIZATIONTASKREQUEST._serialized_end=9370
  _FORCERETRYMATERIALIZATIONTASKRESPONSE._serialized_start=9372
  _FORCERETRYMATERIALIZATIONTASKRESPONSE._serialized_end=9448
  _RESTARTMATERIALIZATIONTASKREQUEST._serialized_start=9450
  _RESTARTMATERIALIZATIONTASKREQUEST._serialized_end=9566
  _RESTARTMATERIALIZATIONTASKRESPONSE._serialized_start=9569
  _RESTARTMATERIALIZATIONTASKRESPONSE._serialized_end=9730
  _GETFCOSREQUEST._serialized_start=9732
  _GETFCOSREQUEST._serialized_end=9778
  _GETFCOSRESPONSE._serialized_start=9780
  _GETFCOSRESPONSE._serialized_end=9867
  _GETSPARKCONFIGREQUEST._serialized_start=9869
  _GETSPARKCONFIGREQUEST._serialized_end=9966
  _SPARKCLUSTERCONFIG._serialized_start=9968
  _SPARKCLUSTERCONFIG._serialized_end=10038
  _GETSPARKCONFIGRESPONSE._serialized_start=10041
  _GETSPARKCONFIGRESPONSE._serialized_end=10237
  _GETMETRICANDEXPECTATIONDEFINITIONREQUEST._serialized_start=10239
  _GETMETRICANDEXPECTATIONDEFINITIONREQUEST._serialized_end=10355
  _GETMETRICANDEXPECTATIONDEFINITIONRESPONSE._serialized_start=10358
  _GETMETRICANDEXPECTATIONDEFINITIONRESPONSE._serialized_end=10714
  _GETFEATUREVIEWREQUEST._serialized_start=10717
  _GETFEATUREVIEWREQUEST._serialized_end=10919
  _GETFEATUREVIEWRESPONSE._serialized_start=10921
  _GETFEATUREVIEWRESPONSE._serialized_end=11015
  _GETFEATUREVIEWSUMMARYREQUEST._serialized_start=11017
  _GETFEATUREVIEWSUMMARYREQUEST._serialized_end=11113
  _GETFEATUREVIEWSUMMARYRESPONSE._serialized_start=11115
  _GETFEATUREVIEWSUMMARYRESPONSE._serialized_end=11210
  _QUERYFEATUREVIEWSREQUEST._serialized_start=11212
  _QUERYFEATUREVIEWSREQUEST._serialized_end=11294
  _QUERYFEATUREVIEWSRESPONSE._serialized_start=11296
  _QUERYFEATUREVIEWSRESPONSE._serialized_end=11393
  _GETMATERIALIZINGFEATUREVIEWSINLIVEWORKSPACESRESPONSE._serialized_start=11395
  _GETMATERIALIZINGFEATUREVIEWSINLIVEWORKSPACESRESPONSE._serialized_end=11518
  _GETVIRTUALDATASOURCEREQUEST._serialized_start=11521
  _GETVIRTUALDATASOURCEREQUEST._serialized_end=11764
  _GETVIRTUALDATASOURCERESPONSE._serialized_start=11766
  _GETVIRTUALDATASOURCERESPONSE._serialized_end=11866
  _GETALLVIRTUALDATASOURCESREQUEST._serialized_start=11868
  _GETALLVIRTUALDATASOURCESREQUEST._serialized_end=11931
  _GETALLVIRTUALDATASOURCESRESPONSE._serialized_start=11933
  _GETALLVIRTUALDATASOURCESRESPONSE._serialized_end=12055
  _GETENTITYREQUEST._serialized_start=12058
  _GETENTITYREQUEST._serialized_end=12266
  _GETENTITYRESPONSE._serialized_start=12268
  _GETENTITYRESPONSE._serialized_end=12357
  _GETALLENTITIESREQUEST._serialized_start=12359
  _GETALLENTITIESREQUEST._serialized_end=12412
  _GETALLENTITIESRESPONSE._serialized_start=12414
  _GETALLENTITIESRESPONSE._serialized_end=12493
  _GETTRANSFORMATIONREQUEST._serialized_start=12496
  _GETTRANSFORMATIONREQUEST._serialized_end=12728
  _GETTRANSFORMATIONRESPONSE._serialized_start=12730
  _GETTRANSFORMATIONRESPONSE._serialized_end=12833
  _GETALLTRANSFORMATIONSREQUEST._serialized_start=12835
  _GETALLTRANSFORMATIONSREQUEST._serialized_end=12895
  _GETALLTRANSFORMATIONSRESPONSE._serialized_start=12897
  _GETALLTRANSFORMATIONSRESPONSE._serialized_end=13011
  _MODELINFO._serialized_start=13014
  _MODELINFO._serialized_end=13176
  _LISTMODELSREQUEST._serialized_start=13178
  _LISTMODELSREQUEST._serialized_end=13221
  _LISTMODELSRESPONSE._serialized_start=13223
  _LISTMODELSRESPONSE._serialized_end=13308
  _GETMODELINFOREQUEST._serialized_start=13310
  _GETMODELINFOREQUEST._serialized_end=13351
  _GETMODELINFORESPONSE._serialized_start=13353
  _GETMODELINFORESPONSE._serialized_end=13447
  _FINDFCOWORKSPACEREQUEST._serialized_start=13449
  _FINDFCOWORKSPACEREQUEST._serialized_end=13539
  _FINDFCOWORKSPACERESPONSE._serialized_start=13541
  _FINDFCOWORKSPACERESPONSE._serialized_end=13597
  _INGESTCLIENTLOGSREQUEST._serialized_start=13599
  _INGESTCLIENTLOGSREQUEST._serialized_end=13721
  _INGESTANALYTICSREQUEST._serialized_start=13723
  _INGESTANALYTICSREQUEST._serialized_end=13841
  _NEWSTATEUPDATEREQUEST._serialized_start=13844
  _NEWSTATEUPDATEREQUEST._serialized_end=14035
  _NEWSTATEUPDATEREQUESTV2._serialized_start=14038
  _NEWSTATEUPDATEREQUESTV2._serialized_end=14336
  _NEWSTATEUPDATERESPONSE._serialized_start=14339
  _NEWSTATEUPDATERESPONSE._serialized_end=14570
  _NEWSTATEUPDATERESPONSEV2._serialized_start=14573
  _NEWSTATEUPDATERESPONSEV2._serialized_end=14808
  _QUERYSTATEUPDATEREQUEST._serialized_start=14810
  _QUERYSTATEUPDATEREQUEST._serialized_end=14917
  _QUERYSTATEUPDATEREQUESTV2._serialized_start=14920
  _QUERYSTATEUPDATEREQUESTV2._serialized_end=15134
  _QUERYSTATEUPDATERESPONSE._serialized_start=15137
  _QUERYSTATEUPDATERESPONSE._serialized_end=15477
  _QUERYSTATEUPDATERESPONSEV2._serialized_start=15480
  _QUERYSTATEUPDATERESPONSEV2._serialized_end=15841
  _GETSTATEUPDATEPLANSUMMARYREQUEST._serialized_start=15843
  _GETSTATEUPDATEPLANSUMMARYREQUEST._serialized_end=15927
  _GETSTATEUPDATEPLANSUMMARYRESPONSE._serialized_start=15929
  _GETSTATEUPDATEPLANSUMMARYRESPONSE._serialized_end=16027
  _APPLYSTATEUPDATEREQUEST._serialized_start=16029
  _APPLYSTATEUPDATEREQUEST._serialized_end=16141
  _APPLYSTATEUPDATERESPONSE._serialized_start=16143
  _APPLYSTATEUPDATERESPONSE._serialized_end=16169
  _GETCONFIGSRESPONSE._serialized_start=16172
  _GETCONFIGSRESPONSE._serialized_end=16350
  _GETCONFIGSRESPONSE_KEYVALUESENTRY._serialized_start=16290
  _GETCONFIGSRESPONSE_KEYVALUESENTRY._serialized_end=16350
  _GETGLOBALSFORWEBUIRESPONSE._serialized_start=16353
  _GETGLOBALSFORWEBUIRESPONSE._serialized_end=16547
  _GETGLOBALSFORWEBUIRESPONSE_KEYVALUESENTRY._serialized_start=16290
  _GETGLOBALSFORWEBUIRESPONSE_KEYVALUESENTRY._serialized_end=16350
  _GETSTATEUPDATELOGREQUEST._serialized_start=16549
  _GETSTATEUPDATELOGREQUEST._serialized_end=16627
  _GETSTATEUPDATELOGRESPONSE._serialized_start=16629
  _GETSTATEUPDATELOGRESPONSE._serialized_end=16719
  _GETSTATEUPDATEPLANLISTREQUEST._serialized_start=16721
  _GETSTATEUPDATEPLANLISTREQUEST._serialized_end=16804
  _GETSTATEUPDATEPLANLISTRESPONSE._serialized_start=16806
  _GETSTATEUPDATEPLANLISTRESPONSE._serialized_end=16901
  _GETRESTOREINFOREQUEST._serialized_start=16903
  _GETRESTOREINFOREQUEST._serialized_end=16985
  _GETRESTOREINFORESPONSE._serialized_start=16988
  _GETRESTOREINFORESPONSE._serialized_end=17138
  _CREATEWORKSPACEREQUEST._serialized_start=17141
  _CREATEWORKSPACEREQUEST._serialized_end=17306
  _DELETEWORKSPACEREQUEST._serialized_start=17308
  _DELETEWORKSPACEREQUEST._serialized_end=17371
  _INTROSPECTAPIKEYREQUEST._serialized_start=17373
  _INTROSPECTAPIKEYREQUEST._serialized_end=17423
  _INTROSPECTAPIKEYRESPONSE._serialized_start=17426
  _INTROSPECTAPIKEYRESPONSE._serialized_end=17629
  _CREATEAPIKEYREQUEST._serialized_start=17631
  _CREATEAPIKEYREQUEST._serialized_end=17731
  _CREATEAPIKEYRESPONSE._serialized_start=17733
  _CREATEAPIKEYRESPONSE._serialized_end=17823
  _DELETEAPIKEYREQUEST._serialized_start=17825
  _DELETEAPIKEYREQUEST._serialized_end=17896
  _LISTAPIKEYSREQUEST._serialized_start=17898
  _LISTAPIKEYSREQUEST._serialized_end=17961
  _LISTAPIKEYSRESPONSE._serialized_start=17963
  _LISTAPIKEYSRESPONSE._serialized_end=18044
  _SERVICEACCOUNT._serialized_start=18047
  _SERVICEACCOUNT._serialized_end=18293
  _CREATESERVICEACCOUNTREQUEST._serialized_start=18295
  _CREATESERVICEACCOUNTREQUEST._serialized_end=18396
  _CREATESERVICEACCOUNTRESPONSE._serialized_start=18399
  _CREATESERVICEACCOUNTRESPONSE._serialized_end=18648
  _GETSERVICEACCOUNTSREQUEST._serialized_start=18650
  _GETSERVICEACCOUNTSREQUEST._serialized_end=18719
  _GETSERVICEACCOUNTSRESPONSE._serialized_start=18721
  _GETSERVICEACCOUNTSRESPONSE._serialized_end=18838
  _UPDATESERVICEACCOUNTREQUEST._serialized_start=18841
  _UPDATESERVICEACCOUNTREQUEST._serialized_end=19005
  _UPDATESERVICEACCOUNTRESPONSE._serialized_start=19008
  _UPDATESERVICEACCOUNTRESPONSE._serialized_end=19232
  _DELETESERVICEACCOUNTREQUEST._serialized_start=19234
  _DELETESERVICEACCOUNTREQUEST._serialized_end=19288
  _DELETESERVICEACCOUNTRESPONSE._serialized_start=19290
  _DELETESERVICEACCOUNTRESPONSE._serialized_end=19320
  _LISTWORKSPACESREQUEST._serialized_start=19322
  _LISTWORKSPACESREQUEST._serialized_end=19345
  _LISTWORKSPACESRESPONSE._serialized_start=19347
  _LISTWORKSPACESRESPONSE._serialized_end=19433
  _GETWORKSPACEREQUEST._serialized_start=19435
  _GETWORKSPACEREQUEST._serialized_end=19495
  _GETWORKSPACERESPONSE._serialized_start=19497
  _GETWORKSPACERESPONSE._serialized_end=19579
  _CREATESAVEDFEATUREDATAFRAMEREQUEST._serialized_start=19582
  _CREATESAVEDFEATUREDATAFRAMEREQUEST._serialized_end=19985
  _CREATESAVEDFEATUREDATAFRAMERESPONSE._serialized_start=19988
  _CREATESAVEDFEATUREDATAFRAMERESPONSE._serialized_end=20123
  _ARCHIVESAVEDFEATUREDATAFRAMEREQUEST._serialized_start=20125
  _ARCHIVESAVEDFEATUREDATAFRAMEREQUEST._serialized_end=20248
  _ARCHIVESAVEDFEATUREDATAFRAMERESPONSE._serialized_start=20250
  _ARCHIVESAVEDFEATUREDATAFRAMERESPONSE._serialized_end=20288
  _GETSAVEDFEATUREDATAFRAMEREQUEST._serialized_start=20291
  _GETSAVEDFEATUREDATAFRAMEREQUEST._serialized_end=20522
  _GETCLUSTERADMININFORESPONSE._serialized_start=20525
  _GETCLUSTERADMININFORESPONSE._serialized_end=20690
  _CREATECLUSTERUSERREQUEST._serialized_start=20692
  _CREATECLUSTERUSERREQUEST._serialized_end=20760
  _CREATECLUSTERUSERRESPONSE._serialized_start=20762
  _CREATECLUSTERUSERRESPONSE._serialized_end=20795
  _DELETECLUSTERUSERREQUEST._serialized_start=20797
  _DELETECLUSTERUSERREQUEST._serialized_end=20857
  _DELETECLUSTERUSERRESPONSE._serialized_start=20859
  _DELETECLUSTERUSERRESPONSE._serialized_end=20892
  _CLUSTERUSERACTIONREQUEST._serialized_start=20895
  _CLUSTERUSERACTIONREQUEST._serialized_end=21166
  _CLUSTERUSERACTIONRESPONSE._serialized_start=21168
  _CLUSTERUSERACTIONRESPONSE._serialized_end=21201
  _GETSAVEDFEATUREDATAFRAMERESPONSE._serialized_start=21204
  _GETSAVEDFEATUREDATAFRAMERESPONSE._serialized_end=21336
  _GETALLSAVEDFEATUREDATAFRAMESREQUEST._serialized_start=21338
  _GETALLSAVEDFEATUREDATAFRAMESREQUEST._serialized_end=21405
  _GETALLSAVEDFEATUREDATAFRAMESRESPONSE._serialized_start=21408
  _GETALLSAVEDFEATUREDATAFRAMESRESPONSE._serialized_end=21546
  _INGESTDATAFRAMEREQUEST._serialized_start=21549
  _INGESTDATAFRAMEREQUEST._serialized_end=21705
  _INGESTDATAFRAMERESPONSE._serialized_start=21707
  _INGESTDATAFRAMERESPONSE._serialized_end=21732
  _GETNEWINGESTDATAFRAMEINFOREQUEST._serialized_start=21734
  _GETNEWINGESTDATAFRAMEINFOREQUEST._serialized_end=21845
  _GETNEWINGESTDATAFRAMEINFORESPONSE._serialized_start=21847
  _GETNEWINGESTDATAFRAMEINFORESPONSE._serialized_end=21963
  _GETUSERDEPLOYMENTSETTINGSRESPONSE._serialized_start=21966
  _GETUSERDEPLOYMENTSETTINGSRESPONSE._serialized_end=22102
  _UPDATEUSERDEPLOYMENTSETTINGSREQUEST._serialized_start=22105
  _UPDATEUSERDEPLOYMENTSETTINGSREQUEST._serialized_end=22302
  _UPDATEUSERDEPLOYMENTSETTINGSRESPONSE._serialized_start=22304
  _UPDATEUSERDEPLOYMENTSETTINGSRESPONSE._serialized_end=22405
  _GETINTERNALSPARKCLUSTERSTATUSRESPONSE._serialized_start=22407
  _GETINTERNALSPARKCLUSTERSTATUSRESPONSE._serialized_end=22517
  _GETDELETEENTITIESINFOREQUEST._serialized_start=22519
  _GETDELETEENTITIESINFOREQUEST._serialized_end=22626
  _GETDELETEENTITIESINFORESPONSE._serialized_start=22629
  _GETDELETEENTITIESINFORESPONSE._serialized_end=22831
  _DELETEENTITIESREQUEST._serialized_start=22834
  _DELETEENTITIESREQUEST._serialized_end=23153
  _DELETEENTITIESRESPONSE._serialized_start=23155
  _DELETEENTITIESRESPONSE._serialized_end=23204
  _GETFEATUREANALYTICSREQUEST._serialized_start=23206
  _GETFEATUREANALYTICSREQUEST._serialized_end=23234
  _GETFEATUREANALYTICSRESPONSE._serialized_start=23237
  _GETFEATUREANALYTICSRESPONSE._serialized_end=23376
  _GETHIVEMETADATAREQUEST._serialized_start=23379
  _GETHIVEMETADATAREQUEST._serialized_end=23632
  _GETHIVEMETADATAREQUEST_ACTION._serialized_start=23540
  _GETHIVEMETADATAREQUEST_ACTION._serialized_end=23632
  _GETHIVEMETADATARESPONSE._serialized_start=23635
  _GETHIVEMETADATARESPONSE._serialized_end=23860
  _VALIDATELOCALFCOREQUEST._serialized_start=23863
  _VALIDATELOCALFCOREQUEST._serialized_end=24012
  _VALIDATELOCALFCORESPONSE._serialized_start=24015
  _VALIDATELOCALFCORESPONSE._serialized_end=24171
  _GETONBOARDINGSTATUSREQUEST._serialized_start=24173
  _GETONBOARDINGSTATUSREQUEST._serialized_end=24231
  _GETONBOARDINGSTATUSRESPONSE._serialized_start=24234
  _GETONBOARDINGSTATUSRESPONSE._serialized_end=24435
  _GETDATAPLATFORMSETUPSTATUSRESPONSE._serialized_start=24438
  _GETDATAPLATFORMSETUPSTATUSRESPONSE._serialized_end=24584
  _GETOBSERVABILITYCONFIGREQUEST._serialized_start=24586
  _GETOBSERVABILITYCONFIGREQUEST._serialized_end=24691
  _GETOBSERVABILITYCONFIGRESPONSE._serialized_start=24694
  _GETOBSERVABILITYCONFIGRESPONSE._serialized_end=24859
  _QUERYMETRICREQUEST._serialized_start=24862
  _QUERYMETRICREQUEST._serialized_end=25165
  _QUERYMETRICRESPONSE._serialized_start=25168
  _QUERYMETRICRESPONSE._serialized_end=25669
  _GETFEATUREVALIDATIONRESULTREQUEST._serialized_start=25672
  _GETFEATUREVALIDATIONRESULTREQUEST._serialized_end=26184
  _GETFEATUREVALIDATIONRESULTRESPONSE._serialized_start=26187
  _GETFEATUREVALIDATIONRESULTRESPONSE._serialized_end=26372
  _GETFEATUREVALIDATIONSUMMARYREQUEST._serialized_start=26375
  _GETFEATUREVALIDATIONSUMMARYREQUEST._serialized_end=26597
  _GETFEATUREVALIDATIONSUMMARYRESPONSE._serialized_start=26600
  _GETFEATUREVALIDATIONSUMMARYRESPONSE._serialized_end=26914
  _GETUSERREQUEST._serialized_start=26916
  _GETUSERREQUEST._serialized_end=26970
  _GETUSERRESPONSE._serialized_start=26972
  _GETUSERRESPONSE._serialized_end=27039
  _FEATURESERVERAUTOSCALINGCONFIG._serialized_start=27042
  _FEATURESERVERAUTOSCALINGCONFIG._serialized_end=27203
  _GETFEATURESERVERCONFIGREQUEST._serialized_start=27205
  _GETFEATURESERVERCONFIGREQUEST._serialized_end=27236
  _GETFEATURESERVERCONFIGRESPONSE._serialized_start=27239
  _GETFEATURESERVERCONFIGRESPONSE._serialized_end=27527
  _SETFEATURESERVERCONFIGREQUEST._serialized_start=27530
  _SETFEATURESERVERCONFIGREQUEST._serialized_end=27709
  _GETOFFLINESTORECREDENTIALSREQUEST._serialized_start=27712
  _GETOFFLINESTORECREDENTIALSREQUEST._serialized_end=27893
  _GETOFFLINESTORECREDENTIALSRESPONSE._serialized_start=27895
  _GETOFFLINESTORECREDENTIALSRESPONSE._serialized_end=27986
  _METADATASERVICE._serialized_start=28053
  _METADATASERVICE._serialized_end=44223
# @@protoc_insertion_point(module_scope)
